# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ActiveDirectoryFault import ActiveDirectoryFault as ActiveDirectoryFault
from .ActiveVMsBlockingEVC import ActiveVMsBlockingEVC as ActiveVMsBlockingEVC
from .AdminDisabled import AdminDisabled as AdminDisabled
from .AdminNotDisabled import AdminNotDisabled as AdminNotDisabled
from .AffinityConfigured import AffinityConfigured as AffinityConfigured
from .AgentInstallFailed import AgentInstallFailed as AgentInstallFailed
from .AlreadyBeingManaged import AlreadyBeingManaged as AlreadyBeingManaged
from .AlreadyConnected import AlreadyConnected as AlreadyConnected
from .AlreadyExists import AlreadyExists as AlreadyExists
from .AlreadyUpgraded import AlreadyUpgraded as AlreadyUpgraded
from .AnswerFileUpdateFailed import AnswerFileUpdateFailed as AnswerFileUpdateFailed
from .ApplicationQuiesceFault import ApplicationQuiesceFault as ApplicationQuiesceFault
from .AuthMinimumAdminPermission import AuthMinimumAdminPermission as AuthMinimumAdminPermission
from .BackupBlobReadFailure import BackupBlobReadFailure as BackupBlobReadFailure
from .BackupBlobWriteFailure import BackupBlobWriteFailure as BackupBlobWriteFailure
from .BlockedByFirewall import BlockedByFirewall as BlockedByFirewall
from .CAMServerRefusedConnection import CAMServerRefusedConnection as CAMServerRefusedConnection
from .CannotAccessFile import CannotAccessFile as CannotAccessFile
from .CannotAccessLocalSource import CannotAccessLocalSource as CannotAccessLocalSource
from .CannotAccessNetwork import CannotAccessNetwork as CannotAccessNetwork
from .CannotAccessVmComponent import CannotAccessVmComponent as CannotAccessVmComponent
from .CannotAccessVmConfig import CannotAccessVmConfig as CannotAccessVmConfig
from .CannotAccessVmDevice import CannotAccessVmDevice as CannotAccessVmDevice
from .CannotAccessVmDisk import CannotAccessVmDisk as CannotAccessVmDisk
from .CannotAddHostWithFTVmAsStandalone import CannotAddHostWithFTVmAsStandalone as CannotAddHostWithFTVmAsStandalone
from .CannotAddHostWithFTVmToDifferentCluster import CannotAddHostWithFTVmToDifferentCluster as CannotAddHostWithFTVmToDifferentCluster
from .CannotAddHostWithFTVmToNonHACluster import CannotAddHostWithFTVmToNonHACluster as CannotAddHostWithFTVmToNonHACluster
from .CannotChangeDrsBehaviorForFtSecondary import CannotChangeDrsBehaviorForFtSecondary as CannotChangeDrsBehaviorForFtSecondary
from .CannotChangeHaSettingsForFtSecondary import CannotChangeHaSettingsForFtSecondary as CannotChangeHaSettingsForFtSecondary
from .CannotChangeVsanClusterUuid import CannotChangeVsanClusterUuid as CannotChangeVsanClusterUuid
from .CannotChangeVsanNodeUuid import CannotChangeVsanNodeUuid as CannotChangeVsanNodeUuid
from .CannotComputeFTCompatibleHosts import CannotComputeFTCompatibleHosts as CannotComputeFTCompatibleHosts
from .CannotCreateFile import CannotCreateFile as CannotCreateFile
from .CannotDecryptPasswords import CannotDecryptPasswords as CannotDecryptPasswords
from .CannotDeleteFile import CannotDeleteFile as CannotDeleteFile
from .CannotDisableDrsOnClustersWithVApps import CannotDisableDrsOnClustersWithVApps as CannotDisableDrsOnClustersWithVApps
from .CannotDisableSnapshot import CannotDisableSnapshot as CannotDisableSnapshot
from .CannotDisconnectHostWithFaultToleranceVm import CannotDisconnectHostWithFaultToleranceVm as CannotDisconnectHostWithFaultToleranceVm
from .CannotEnableVmcpForCluster import CannotEnableVmcpForCluster as CannotEnableVmcpForCluster
from .CannotModifyConfigCpuRequirements import CannotModifyConfigCpuRequirements as CannotModifyConfigCpuRequirements
from .CannotMoveFaultToleranceVm import CannotMoveFaultToleranceVm as CannotMoveFaultToleranceVm
from .CannotMoveHostWithFaultToleranceVm import CannotMoveHostWithFaultToleranceVm as CannotMoveHostWithFaultToleranceVm
from .CannotMoveVmWithDeltaDisk import CannotMoveVmWithDeltaDisk as CannotMoveVmWithDeltaDisk
from .CannotMoveVmWithNativeDeltaDisk import CannotMoveVmWithNativeDeltaDisk as CannotMoveVmWithNativeDeltaDisk
from .CannotMoveVsanEnabledHost import CannotMoveVsanEnabledHost as CannotMoveVsanEnabledHost
from .CannotPlaceWithoutPrerequisiteMoves import CannotPlaceWithoutPrerequisiteMoves as CannotPlaceWithoutPrerequisiteMoves
from .CannotPowerOffVmInCluster import CannotPowerOffVmInCluster as CannotPowerOffVmInCluster
from .CannotReconfigureVsanWhenHaEnabled import CannotReconfigureVsanWhenHaEnabled as CannotReconfigureVsanWhenHaEnabled
from .CannotUseNetwork import CannotUseNetwork as CannotUseNetwork
from .ClockSkew import ClockSkew as ClockSkew
from .CloneFromSnapshotNotSupported import CloneFromSnapshotNotSupported as CloneFromSnapshotNotSupported
from .CnsAlreadyRegisteredFault import CnsAlreadyRegisteredFault as CnsAlreadyRegisteredFault
from .CnsFault import CnsFault as CnsFault
from .CnsInCompatibleFault import CnsInCompatibleFault as CnsInCompatibleFault
from .CnsMissingControllerFault import CnsMissingControllerFault as CnsMissingControllerFault
from .CnsMissingPrivilegeFault import CnsMissingPrivilegeFault as CnsMissingPrivilegeFault
from .CnsNotRegisteredFault import CnsNotRegisteredFault as CnsNotRegisteredFault
from .CnsPlacementFault import CnsPlacementFault as CnsPlacementFault
from .CnsRankedLowerFault import CnsRankedLowerFault as CnsRankedLowerFault
from .CnsSnapshotNotFoundFault import CnsSnapshotNotFoundFault as CnsSnapshotNotFoundFault
from .CnsVolumeNotFoundFault import CnsVolumeNotFoundFault as CnsVolumeNotFoundFault
from .CollectorAddressUnset import CollectorAddressUnset as CollectorAddressUnset
from .ConcurrentAccess import ConcurrentAccess as ConcurrentAccess
from .ConflictingConfiguration import ConflictingConfiguration as ConflictingConfiguration
from .ConflictingDatastoreFound import ConflictingDatastoreFound as ConflictingDatastoreFound
from .ConnectedIso import ConnectedIso as ConnectedIso
from .CpuCompatibilityUnknown import CpuCompatibilityUnknown as CpuCompatibilityUnknown
from .CpuHotPlugNotSupported import CpuHotPlugNotSupported as CpuHotPlugNotSupported
from .CpuIncompatible import CpuIncompatible as CpuIncompatible
from .CpuIncompatible1ECX import CpuIncompatible1ECX as CpuIncompatible1ECX
from .CpuIncompatible81EDX import CpuIncompatible81EDX as CpuIncompatible81EDX
from .CustomizationFault import CustomizationFault as CustomizationFault
from .CustomizationPending import CustomizationPending as CustomizationPending
from .DVPortNotSupported import DVPortNotSupported as DVPortNotSupported
from .DasConfigFault import DasConfigFault as DasConfigFault
from .DatabaseError import DatabaseError as DatabaseError
from .DatacenterMismatch import DatacenterMismatch as DatacenterMismatch
from .DatastoreNotWritableOnHost import DatastoreNotWritableOnHost as DatastoreNotWritableOnHost
from .DeltaDiskFormatNotSupported import DeltaDiskFormatNotSupported as DeltaDiskFormatNotSupported
from .DestinationSwitchFull import DestinationSwitchFull as DestinationSwitchFull
from .DestinationVsanDisabled import DestinationVsanDisabled as DestinationVsanDisabled
from .DeviceBackingNotSupported import DeviceBackingNotSupported as DeviceBackingNotSupported
from .DeviceControllerNotSupported import DeviceControllerNotSupported as DeviceControllerNotSupported
from .DeviceHotPlugNotSupported import DeviceHotPlugNotSupported as DeviceHotPlugNotSupported
from .DeviceNotFound import DeviceNotFound as DeviceNotFound
from .DeviceNotSupported import DeviceNotSupported as DeviceNotSupported
from .DeviceUnsupportedForVmPlatform import DeviceUnsupportedForVmPlatform as DeviceUnsupportedForVmPlatform
from .DeviceUnsupportedForVmVersion import DeviceUnsupportedForVmVersion as DeviceUnsupportedForVmVersion
from .DigestNotSupported import DigestNotSupported as DigestNotSupported
from .DirectoryNotEmpty import DirectoryNotEmpty as DirectoryNotEmpty
from .DisableAdminNotSupported import DisableAdminNotSupported as DisableAdminNotSupported
from .DisallowedChangeByService import DisallowedChangeByService as DisallowedChangeByService
from .DisallowedDiskModeChange import DisallowedDiskModeChange as DisallowedDiskModeChange
from .DisallowedMigrationDeviceAttached import DisallowedMigrationDeviceAttached as DisallowedMigrationDeviceAttached
from .DisallowedOperationOnFailoverHost import DisallowedOperationOnFailoverHost as DisallowedOperationOnFailoverHost
from .DisconnectedHostsBlockingEVC import DisconnectedHostsBlockingEVC as DisconnectedHostsBlockingEVC
from .DiskHasPartitions import DiskHasPartitions as DiskHasPartitions
from .DiskIsLastRemainingNonSSD import DiskIsLastRemainingNonSSD as DiskIsLastRemainingNonSSD
from .DiskIsNonLocal import DiskIsNonLocal as DiskIsNonLocal
from .DiskIsUSB import DiskIsUSB as DiskIsUSB
from .DiskMoveTypeNotSupported import DiskMoveTypeNotSupported as DiskMoveTypeNotSupported
from .DiskNotSupported import DiskNotSupported as DiskNotSupported
from .DiskTooSmall import DiskTooSmall as DiskTooSmall
from .DomainNotFound import DomainNotFound as DomainNotFound
from .DrsDisabledOnVm import DrsDisabledOnVm as DrsDisabledOnVm
from .DrsVmotionIncompatibleFault import DrsVmotionIncompatibleFault as DrsVmotionIncompatibleFault
from .DuplicateDisks import DuplicateDisks as DuplicateDisks
from .DuplicateName import DuplicateName as DuplicateName
from .DuplicateVsanNetworkInterface import DuplicateVsanNetworkInterface as DuplicateVsanNetworkInterface
from .DvsApplyOperationFault import DvsApplyOperationFault as DvsApplyOperationFault
from .DvsFault import DvsFault as DvsFault
from .DvsNotAuthorized import DvsNotAuthorized as DvsNotAuthorized
from .DvsOperationBulkFault import DvsOperationBulkFault as DvsOperationBulkFault
from .DvsScopeViolated import DvsScopeViolated as DvsScopeViolated
from .EVCAdmissionFailed import EVCAdmissionFailed as EVCAdmissionFailed
from .EVCAdmissionFailedCPUFeaturesForMode import EVCAdmissionFailedCPUFeaturesForMode as EVCAdmissionFailedCPUFeaturesForMode
from .EVCAdmissionFailedCPUModel import EVCAdmissionFailedCPUModel as EVCAdmissionFailedCPUModel
from .EVCAdmissionFailedCPUModelForMode import EVCAdmissionFailedCPUModelForMode as EVCAdmissionFailedCPUModelForMode
from .EVCAdmissionFailedCPUVendor import EVCAdmissionFailedCPUVendor as EVCAdmissionFailedCPUVendor
from .EVCAdmissionFailedCPUVendorUnknown import EVCAdmissionFailedCPUVendorUnknown as EVCAdmissionFailedCPUVendorUnknown
from .EVCAdmissionFailedHostDisconnected import EVCAdmissionFailedHostDisconnected as EVCAdmissionFailedHostDisconnected
from .EVCAdmissionFailedHostSoftware import EVCAdmissionFailedHostSoftware as EVCAdmissionFailedHostSoftware
from .EVCAdmissionFailedHostSoftwareForMode import EVCAdmissionFailedHostSoftwareForMode as EVCAdmissionFailedHostSoftwareForMode
from .EVCAdmissionFailedVmActive import EVCAdmissionFailedVmActive as EVCAdmissionFailedVmActive
from .EVCConfigFault import EVCConfigFault as EVCConfigFault
from .EVCModeIllegalByVendor import EVCModeIllegalByVendor as EVCModeIllegalByVendor
from .EVCModeUnsupportedByHosts import EVCModeUnsupportedByHosts as EVCModeUnsupportedByHosts
from .EVCUnsupportedByHostHardware import EVCUnsupportedByHostHardware as EVCUnsupportedByHostHardware
from .EVCUnsupportedByHostSoftware import EVCUnsupportedByHostSoftware as EVCUnsupportedByHostSoftware
from .EightHostLimitViolated import EightHostLimitViolated as EightHostLimitViolated
from .EncryptionKeyRequired import EncryptionKeyRequired as EncryptionKeyRequired
from .ExpiredAddonLicense import ExpiredAddonLicense as ExpiredAddonLicense
from .ExpiredEditionLicense import ExpiredEditionLicense as ExpiredEditionLicense
from .ExpiredFeatureLicense import ExpiredFeatureLicense as ExpiredFeatureLicense
from .ExtendedFault import ExtendedFault as ExtendedFault
from .FailToEnableSPBM import FailToEnableSPBM as FailToEnableSPBM
from .FailToLockFaultToleranceVMs import FailToLockFaultToleranceVMs as FailToLockFaultToleranceVMs
from .FaultToleranceAntiAffinityViolated import FaultToleranceAntiAffinityViolated as FaultToleranceAntiAffinityViolated
from .FaultToleranceCannotEditMem import FaultToleranceCannotEditMem as FaultToleranceCannotEditMem
from .FaultToleranceCpuIncompatible import FaultToleranceCpuIncompatible as FaultToleranceCpuIncompatible
from .FaultToleranceNeedsThickDisk import FaultToleranceNeedsThickDisk as FaultToleranceNeedsThickDisk
from .FaultToleranceNotLicensed import FaultToleranceNotLicensed as FaultToleranceNotLicensed
from .FaultToleranceNotSameBuild import FaultToleranceNotSameBuild as FaultToleranceNotSameBuild
from .FaultTolerancePrimaryPowerOnNotAttempted import FaultTolerancePrimaryPowerOnNotAttempted as FaultTolerancePrimaryPowerOnNotAttempted
from .FaultToleranceVmNotDasProtected import FaultToleranceVmNotDasProtected as FaultToleranceVmNotDasProtected
from .FcoeFault import FcoeFault as FcoeFault
from .FcoeFaultPnicHasNoPortSet import FcoeFaultPnicHasNoPortSet as FcoeFaultPnicHasNoPortSet
from .FeatureRequirementsNotMet import FeatureRequirementsNotMet as FeatureRequirementsNotMet
from .FileAlreadyExists import FileAlreadyExists as FileAlreadyExists
from .FileBackedPortNotSupported import FileBackedPortNotSupported as FileBackedPortNotSupported
from .FileFault import FileFault as FileFault
from .FileLocked import FileLocked as FileLocked
from .FileNameTooLong import FileNameTooLong as FileNameTooLong
from .FileNotFound import FileNotFound as FileNotFound
from .FileNotWritable import FileNotWritable as FileNotWritable
from .FileTooLarge import FileTooLarge as FileTooLarge
from .FilesystemQuiesceFault import FilesystemQuiesceFault as FilesystemQuiesceFault
from .FilterInUse import FilterInUse as FilterInUse
from .FtIssuesOnHost import FtIssuesOnHost as FtIssuesOnHost
from .FtVmHostRuleViolation import FtVmHostRuleViolation as FtVmHostRuleViolation
from .FullStorageVMotionNotSupported import FullStorageVMotionNotSupported as FullStorageVMotionNotSupported
from .GatewayConnectFault import GatewayConnectFault as GatewayConnectFault
from .GatewayHostNotReachable import GatewayHostNotReachable as GatewayHostNotReachable
from .GatewayNotFound import GatewayNotFound as GatewayNotFound
from .GatewayNotReachable import GatewayNotReachable as GatewayNotReachable
from .GatewayOperationRefused import GatewayOperationRefused as GatewayOperationRefused
from .GatewayToHostAuthFault import GatewayToHostAuthFault as GatewayToHostAuthFault
from .GatewayToHostConnectFault import GatewayToHostConnectFault as GatewayToHostConnectFault
from .GatewayToHostTrustVerifyFault import GatewayToHostTrustVerifyFault as GatewayToHostTrustVerifyFault
from .GenericDrsFault import GenericDrsFault as GenericDrsFault
from .GenericVmConfigFault import GenericVmConfigFault as GenericVmConfigFault
from .GuestAuthenticationChallenge import GuestAuthenticationChallenge as GuestAuthenticationChallenge
from .GuestComponentsOutOfDate import GuestComponentsOutOfDate as GuestComponentsOutOfDate
from .GuestMultipleMappings import GuestMultipleMappings as GuestMultipleMappings
from .GuestOperationsFault import GuestOperationsFault as GuestOperationsFault
from .GuestOperationsUnavailable import GuestOperationsUnavailable as GuestOperationsUnavailable
from .GuestPermissionDenied import GuestPermissionDenied as GuestPermissionDenied
from .GuestProcessNotFound import GuestProcessNotFound as GuestProcessNotFound
from .GuestRegistryFault import GuestRegistryFault as GuestRegistryFault
from .GuestRegistryKeyAlreadyExists import GuestRegistryKeyAlreadyExists as GuestRegistryKeyAlreadyExists
from .GuestRegistryKeyFault import GuestRegistryKeyFault as GuestRegistryKeyFault
from .GuestRegistryKeyHasSubkeys import GuestRegistryKeyHasSubkeys as GuestRegistryKeyHasSubkeys
from .GuestRegistryKeyInvalid import GuestRegistryKeyInvalid as GuestRegistryKeyInvalid
from .GuestRegistryKeyParentVolatile import GuestRegistryKeyParentVolatile as GuestRegistryKeyParentVolatile
from .GuestRegistryValueFault import GuestRegistryValueFault as GuestRegistryValueFault
from .GuestRegistryValueNotFound import GuestRegistryValueNotFound as GuestRegistryValueNotFound
from .HAErrorsAtDest import HAErrorsAtDest as HAErrorsAtDest
from .HeterogenousHostsBlockingEVC import HeterogenousHostsBlockingEVC as HeterogenousHostsBlockingEVC
from .HostAccessRestrictedToManagementServer import HostAccessRestrictedToManagementServer as HostAccessRestrictedToManagementServer
from .HostConfigFailed import HostConfigFailed as HostConfigFailed
from .HostConfigFault import HostConfigFault as HostConfigFault
from .HostConnectFault import HostConnectFault as HostConnectFault
from .HostHasComponentFailure import HostHasComponentFailure as HostHasComponentFailure
from .HostInDomain import HostInDomain as HostInDomain
from .HostIncompatibleForFaultTolerance import HostIncompatibleForFaultTolerance as HostIncompatibleForFaultTolerance
from .HostIncompatibleForRecordReplay import HostIncompatibleForRecordReplay as HostIncompatibleForRecordReplay
from .HostInventoryFull import HostInventoryFull as HostInventoryFull
from .HostPowerOpFailed import HostPowerOpFailed as HostPowerOpFailed
from .HostSpecificationOperationFailed import HostSpecificationOperationFailed as HostSpecificationOperationFailed
from .HotSnapshotMoveNotSupported import HotSnapshotMoveNotSupported as HotSnapshotMoveNotSupported
from .HttpFault import HttpFault as HttpFault
from .IDEDiskNotSupported import IDEDiskNotSupported as IDEDiskNotSupported
from .IORMNotSupportedHostOnDatastore import IORMNotSupportedHostOnDatastore as IORMNotSupportedHostOnDatastore
from .ImportHostAddFailure import ImportHostAddFailure as ImportHostAddFailure
from .ImportOperationBulkFault import ImportOperationBulkFault as ImportOperationBulkFault
from .InUseFeatureManipulationDisallowed import InUseFeatureManipulationDisallowed as InUseFeatureManipulationDisallowed
from .InaccessibleDatastore import InaccessibleDatastore as InaccessibleDatastore
from .InaccessibleFTMetadataDatastore import InaccessibleFTMetadataDatastore as InaccessibleFTMetadataDatastore
from .InaccessibleVFlashSource import InaccessibleVFlashSource as InaccessibleVFlashSource
from .IncompatibleDefaultDevice import IncompatibleDefaultDevice as IncompatibleDefaultDevice
from .IncompatibleHostForFtSecondary import IncompatibleHostForFtSecondary as IncompatibleHostForFtSecondary
from .IncompatibleHostForVmReplication import IncompatibleHostForVmReplication as IncompatibleHostForVmReplication
from .IncompatibleSetting import IncompatibleSetting as IncompatibleSetting
from .IncorrectFileType import IncorrectFileType as IncorrectFileType
from .IncorrectHostInformation import IncorrectHostInformation as IncorrectHostInformation
from .IndependentDiskVMotionNotSupported import IndependentDiskVMotionNotSupported as IndependentDiskVMotionNotSupported
from .InsufficientAgentVmsDeployed import InsufficientAgentVmsDeployed as InsufficientAgentVmsDeployed
from .InsufficientCpuResourcesFault import InsufficientCpuResourcesFault as InsufficientCpuResourcesFault
from .InsufficientDisks import InsufficientDisks as InsufficientDisks
from .InsufficientFailoverResourcesFault import InsufficientFailoverResourcesFault as InsufficientFailoverResourcesFault
from .InsufficientGraphicsResourcesFault import InsufficientGraphicsResourcesFault as InsufficientGraphicsResourcesFault
from .InsufficientHostCapacityFault import InsufficientHostCapacityFault as InsufficientHostCapacityFault
from .InsufficientHostCpuCapacityFault import InsufficientHostCpuCapacityFault as InsufficientHostCpuCapacityFault
from .InsufficientHostMemoryCapacityFault import InsufficientHostMemoryCapacityFault as InsufficientHostMemoryCapacityFault
from .InsufficientMemoryResourcesFault import InsufficientMemoryResourcesFault as InsufficientMemoryResourcesFault
from .InsufficientNetworkCapacity import InsufficientNetworkCapacity as InsufficientNetworkCapacity
from .InsufficientNetworkResourcePoolCapacity import InsufficientNetworkResourcePoolCapacity as InsufficientNetworkResourcePoolCapacity
from .InsufficientPerCpuCapacity import InsufficientPerCpuCapacity as InsufficientPerCpuCapacity
from .InsufficientResourcesFault import InsufficientResourcesFault as InsufficientResourcesFault
from .InsufficientStandbyCpuResource import InsufficientStandbyCpuResource as InsufficientStandbyCpuResource
from .InsufficientStandbyMemoryResource import InsufficientStandbyMemoryResource as InsufficientStandbyMemoryResource
from .InsufficientStandbyResource import InsufficientStandbyResource as InsufficientStandbyResource
from .InsufficientStorageIops import InsufficientStorageIops as InsufficientStorageIops
from .InsufficientStorageSpace import InsufficientStorageSpace as InsufficientStorageSpace
from .InsufficientVFlashResourcesFault import InsufficientVFlashResourcesFault as InsufficientVFlashResourcesFault
from .InvalidAffinitySettingFault import InvalidAffinitySettingFault as InvalidAffinitySettingFault
from .InvalidBmcRole import InvalidBmcRole as InvalidBmcRole
from .InvalidBundle import InvalidBundle as InvalidBundle
from .InvalidCAMCertificate import InvalidCAMCertificate as InvalidCAMCertificate
from .InvalidCAMServer import InvalidCAMServer as InvalidCAMServer
from .InvalidClientCertificate import InvalidClientCertificate as InvalidClientCertificate
from .InvalidController import InvalidController as InvalidController
from .InvalidDasConfigArgument import InvalidDasConfigArgument as InvalidDasConfigArgument
from .InvalidDasRestartPriorityForFtVm import InvalidDasRestartPriorityForFtVm as InvalidDasRestartPriorityForFtVm
from .InvalidDatastore import InvalidDatastore as InvalidDatastore
from .InvalidDatastorePath import InvalidDatastorePath as InvalidDatastorePath
from .InvalidDatastoreState import InvalidDatastoreState as InvalidDatastoreState
from .InvalidDeviceBacking import InvalidDeviceBacking as InvalidDeviceBacking
from .InvalidDeviceOperation import InvalidDeviceOperation as InvalidDeviceOperation
from .InvalidDeviceSpec import InvalidDeviceSpec as InvalidDeviceSpec
from .InvalidDiskFormat import InvalidDiskFormat as InvalidDiskFormat
from .InvalidDrsBehaviorForFtVm import InvalidDrsBehaviorForFtVm as InvalidDrsBehaviorForFtVm
from .InvalidEditionLicense import InvalidEditionLicense as InvalidEditionLicense
from .InvalidEvent import InvalidEvent as InvalidEvent
from .InvalidFolder import InvalidFolder as InvalidFolder
from .InvalidFormat import InvalidFormat as InvalidFormat
from .InvalidGuestLogin import InvalidGuestLogin as InvalidGuestLogin
from .InvalidHostConnectionState import InvalidHostConnectionState as InvalidHostConnectionState
from .InvalidHostName import InvalidHostName as InvalidHostName
from .InvalidHostState import InvalidHostState as InvalidHostState
from .InvalidIndexArgument import InvalidIndexArgument as InvalidIndexArgument
from .InvalidIpfixConfig import InvalidIpfixConfig as InvalidIpfixConfig
from .InvalidIpmiLoginInfo import InvalidIpmiLoginInfo as InvalidIpmiLoginInfo
from .InvalidIpmiMacAddress import InvalidIpmiMacAddress as InvalidIpmiMacAddress
from .InvalidLicense import InvalidLicense as InvalidLicense
from .InvalidLocale import InvalidLocale as InvalidLocale
from .InvalidLogin import InvalidLogin as InvalidLogin
from .InvalidName import InvalidName as InvalidName
from .InvalidNasCredentials import InvalidNasCredentials as InvalidNasCredentials
from .InvalidNetworkInType import InvalidNetworkInType as InvalidNetworkInType
from .InvalidNetworkResource import InvalidNetworkResource as InvalidNetworkResource
from .InvalidOperationOnSecondaryVm import InvalidOperationOnSecondaryVm as InvalidOperationOnSecondaryVm
from .InvalidPowerState import InvalidPowerState as InvalidPowerState
from .InvalidPrivilege import InvalidPrivilege as InvalidPrivilege
from .InvalidProfileReferenceHost import InvalidProfileReferenceHost as InvalidProfileReferenceHost
from .InvalidPropertyType import InvalidPropertyType as InvalidPropertyType
from .InvalidPropertyValue import InvalidPropertyValue as InvalidPropertyValue
from .InvalidResourcePoolStructureFault import InvalidResourcePoolStructureFault as InvalidResourcePoolStructureFault
from .InvalidScheduledTask import InvalidScheduledTask as InvalidScheduledTask
from .InvalidSnapshotFormat import InvalidSnapshotFormat as InvalidSnapshotFormat
from .InvalidState import InvalidState as InvalidState
from .InvalidVmConfig import InvalidVmConfig as InvalidVmConfig
from .InvalidVmState import InvalidVmState as InvalidVmState
from .InventoryHasStandardAloneHosts import InventoryHasStandardAloneHosts as InventoryHasStandardAloneHosts
from .IpHostnameGeneratorError import IpHostnameGeneratorError as IpHostnameGeneratorError
from .IscsiFault import IscsiFault as IscsiFault
from .IscsiFaultInvalidVnic import IscsiFaultInvalidVnic as IscsiFaultInvalidVnic
from .IscsiFaultPnicInUse import IscsiFaultPnicInUse as IscsiFaultPnicInUse
from .IscsiFaultVnicAlreadyBound import IscsiFaultVnicAlreadyBound as IscsiFaultVnicAlreadyBound
from .IscsiFaultVnicHasActivePaths import IscsiFaultVnicHasActivePaths as IscsiFaultVnicHasActivePaths
from .IscsiFaultVnicHasMultipleUplinks import IscsiFaultVnicHasMultipleUplinks as IscsiFaultVnicHasMultipleUplinks
from .IscsiFaultVnicHasNoUplinks import IscsiFaultVnicHasNoUplinks as IscsiFaultVnicHasNoUplinks
from .IscsiFaultVnicHasWrongUplink import IscsiFaultVnicHasWrongUplink as IscsiFaultVnicHasWrongUplink
from .IscsiFaultVnicInUse import IscsiFaultVnicInUse as IscsiFaultVnicInUse
from .IscsiFaultVnicIsLastPath import IscsiFaultVnicIsLastPath as IscsiFaultVnicIsLastPath
from .IscsiFaultVnicNotBound import IscsiFaultVnicNotBound as IscsiFaultVnicNotBound
from .IscsiFaultVnicNotFound import IscsiFaultVnicNotFound as IscsiFaultVnicNotFound
from .KeyNotFound import KeyNotFound as KeyNotFound
from .LargeRDMConversionNotSupported import LargeRDMConversionNotSupported as LargeRDMConversionNotSupported
from .LargeRDMNotSupportedOnDatastore import LargeRDMNotSupportedOnDatastore as LargeRDMNotSupportedOnDatastore
from .LegacyNetworkInterfaceInUse import LegacyNetworkInterfaceInUse as LegacyNetworkInterfaceInUse
from .LicenseAssignmentFailed import LicenseAssignmentFailed as LicenseAssignmentFailed
from .LicenseDowngradeDisallowed import LicenseDowngradeDisallowed as LicenseDowngradeDisallowed
from .LicenseEntityNotFound import LicenseEntityNotFound as LicenseEntityNotFound
from .LicenseExpired import LicenseExpired as LicenseExpired
from .LicenseKeyEntityMismatch import LicenseKeyEntityMismatch as LicenseKeyEntityMismatch
from .LicenseRestricted import LicenseRestricted as LicenseRestricted
from .LicenseServerUnavailable import LicenseServerUnavailable as LicenseServerUnavailable
from .LicenseSourceUnavailable import LicenseSourceUnavailable as LicenseSourceUnavailable
from .LimitExceeded import LimitExceeded as LimitExceeded
from .LinuxVolumeNotClean import LinuxVolumeNotClean as LinuxVolumeNotClean
from .LogBundlingFailed import LogBundlingFailed as LogBundlingFailed
from .MaintenanceModeFileMove import MaintenanceModeFileMove as MaintenanceModeFileMove
from .MemoryFileFormatNotSupportedByDatastore import MemoryFileFormatNotSupportedByDatastore as MemoryFileFormatNotSupportedByDatastore
from .MemoryHotPlugNotSupported import MemoryHotPlugNotSupported as MemoryHotPlugNotSupported
from .MemorySizeNotRecommended import MemorySizeNotRecommended as MemorySizeNotRecommended
from .MemorySizeNotSupported import MemorySizeNotSupported as MemorySizeNotSupported
from .MemorySizeNotSupportedByDatastore import MemorySizeNotSupportedByDatastore as MemorySizeNotSupportedByDatastore
from .MemorySnapshotOnIndependentDisk import MemorySnapshotOnIndependentDisk as MemorySnapshotOnIndependentDisk
from .MethodAlreadyDisabledFault import MethodAlreadyDisabledFault as MethodAlreadyDisabledFault
from .MethodDisabled import MethodDisabled as MethodDisabled
from .MigrationDisabled import MigrationDisabled as MigrationDisabled
from .MigrationFault import MigrationFault as MigrationFault
from .MigrationFeatureNotSupported import MigrationFeatureNotSupported as MigrationFeatureNotSupported
from .MigrationNotReady import MigrationNotReady as MigrationNotReady
from .MismatchedBundle import MismatchedBundle as MismatchedBundle
from .MismatchedNetworkPolicies import MismatchedNetworkPolicies as MismatchedNetworkPolicies
from .MismatchedVMotionNetworkNames import MismatchedVMotionNetworkNames as MismatchedVMotionNetworkNames
from .MissingBmcSupport import MissingBmcSupport as MissingBmcSupport
from .MissingController import MissingController as MissingController
from .MissingIpPool import MissingIpPool as MissingIpPool
from .MissingLinuxCustResources import MissingLinuxCustResources as MissingLinuxCustResources
from .MissingNetworkIpConfig import MissingNetworkIpConfig as MissingNetworkIpConfig
from .MissingPowerOffConfiguration import MissingPowerOffConfiguration as MissingPowerOffConfiguration
from .MissingPowerOnConfiguration import MissingPowerOnConfiguration as MissingPowerOnConfiguration
from .MissingWindowsCustResources import MissingWindowsCustResources as MissingWindowsCustResources
from .MksConnectionLimitReached import MksConnectionLimitReached as MksConnectionLimitReached
from .MountError import MountError as MountError
from .MultiWriterNotSupported import MultiWriterNotSupported as MultiWriterNotSupported
from .MultipleCertificatesVerifyFault import MultipleCertificatesVerifyFault as MultipleCertificatesVerifyFault
from .MultipleSnapshotsNotSupported import MultipleSnapshotsNotSupported as MultipleSnapshotsNotSupported
from .NamespaceFull import NamespaceFull as NamespaceFull
from .NamespaceLimitReached import NamespaceLimitReached as NamespaceLimitReached
from .NamespaceWriteProtected import NamespaceWriteProtected as NamespaceWriteProtected
from .NasConfigFault import NasConfigFault as NasConfigFault
from .NasConnectionLimitReached import NasConnectionLimitReached as NasConnectionLimitReached
from .NasSessionCredentialConflict import NasSessionCredentialConflict as NasSessionCredentialConflict
from .NasVolumeNotMounted import NasVolumeNotMounted as NasVolumeNotMounted
from .NetworkCopyFault import NetworkCopyFault as NetworkCopyFault
from .NetworkDisruptedAndConfigRolledBack import NetworkDisruptedAndConfigRolledBack as NetworkDisruptedAndConfigRolledBack
from .NetworkInaccessible import NetworkInaccessible as NetworkInaccessible
from .NetworksMayNotBeTheSame import NetworksMayNotBeTheSame as NetworksMayNotBeTheSame
from .NicSettingMismatch import NicSettingMismatch as NicSettingMismatch
from .NoActiveHostInCluster import NoActiveHostInCluster as NoActiveHostInCluster
from .NoAvailableIp import NoAvailableIp as NoAvailableIp
from .NoClientCertificate import NoClientCertificate as NoClientCertificate
from .NoCompatibleDatastore import NoCompatibleDatastore as NoCompatibleDatastore
from .NoCompatibleHardAffinityHost import NoCompatibleHardAffinityHost as NoCompatibleHardAffinityHost
from .NoCompatibleHost import NoCompatibleHost as NoCompatibleHost
from .NoCompatibleHostWithAccessToDevice import NoCompatibleHostWithAccessToDevice as NoCompatibleHostWithAccessToDevice
from .NoCompatibleSoftAffinityHost import NoCompatibleSoftAffinityHost as NoCompatibleSoftAffinityHost
from .NoConnectedDatastore import NoConnectedDatastore as NoConnectedDatastore
from .NoDiskFound import NoDiskFound as NoDiskFound
from .NoDiskSpace import NoDiskSpace as NoDiskSpace
from .NoDisksToCustomize import NoDisksToCustomize as NoDisksToCustomize
from .NoGateway import NoGateway as NoGateway
from .NoGuestHeartbeat import NoGuestHeartbeat as NoGuestHeartbeat
from .NoHost import NoHost as NoHost
from .NoHostSuitableForFtSecondary import NoHostSuitableForFtSecondary as NoHostSuitableForFtSecondary
from .NoLicenseServerConfigured import NoLicenseServerConfigured as NoLicenseServerConfigured
from .NoPeerHostFound import NoPeerHostFound as NoPeerHostFound
from .NoPermission import NoPermission as NoPermission
from .NoPermissionOnAD import NoPermissionOnAD as NoPermissionOnAD
from .NoPermissionOnHost import NoPermissionOnHost as NoPermissionOnHost
from .NoPermissionOnNasVolume import NoPermissionOnNasVolume as NoPermissionOnNasVolume
from .NoSubjectName import NoSubjectName as NoSubjectName
from .NoVcManagedIpConfigured import NoVcManagedIpConfigured as NoVcManagedIpConfigured
from .NoVirtualNic import NoVirtualNic as NoVirtualNic
from .NoVmInVApp import NoVmInVApp as NoVmInVApp
from .NonADUserRequired import NonADUserRequired as NonADUserRequired
from .NonHomeRDMVMotionNotSupported import NonHomeRDMVMotionNotSupported as NonHomeRDMVMotionNotSupported
from .NonPersistentDisksNotSupported import NonPersistentDisksNotSupported as NonPersistentDisksNotSupported
from .NonVmwareOuiMacNotSupportedHost import NonVmwareOuiMacNotSupportedHost as NonVmwareOuiMacNotSupportedHost
from .NotADirectory import NotADirectory as NotADirectory
from .NotAFile import NotAFile as NotAFile
from .NotAuthenticated import NotAuthenticated as NotAuthenticated
from .NotEnoughCpus import NotEnoughCpus as NotEnoughCpus
from .NotEnoughLogicalCpus import NotEnoughLogicalCpus as NotEnoughLogicalCpus
from .NotFound import NotFound as NotFound
from .NotSupportedDeviceForFT import NotSupportedDeviceForFT as NotSupportedDeviceForFT
from .NotSupportedHost import NotSupportedHost as NotSupportedHost
from .NotSupportedHostForChecksum import NotSupportedHostForChecksum as NotSupportedHostForChecksum
from .NotSupportedHostForVFlash import NotSupportedHostForVFlash as NotSupportedHostForVFlash
from .NotSupportedHostForVmcp import NotSupportedHostForVmcp as NotSupportedHostForVmcp
from .NotSupportedHostForVmemFile import NotSupportedHostForVmemFile as NotSupportedHostForVmemFile
from .NotSupportedHostForVsan import NotSupportedHostForVsan as NotSupportedHostForVsan
from .NotSupportedHostInCluster import NotSupportedHostInCluster as NotSupportedHostInCluster
from .NotSupportedHostInDvs import NotSupportedHostInDvs as NotSupportedHostInDvs
from .NotSupportedHostInHACluster import NotSupportedHostInHACluster as NotSupportedHostInHACluster
from .NotUserConfigurableProperty import NotUserConfigurableProperty as NotUserConfigurableProperty
from .NumVirtualCoresPerSocketNotSupported import NumVirtualCoresPerSocketNotSupported as NumVirtualCoresPerSocketNotSupported
from .NumVirtualCpusExceedsLimit import NumVirtualCpusExceedsLimit as NumVirtualCpusExceedsLimit
from .NumVirtualCpusIncompatible import NumVirtualCpusIncompatible as NumVirtualCpusIncompatible
from .NumVirtualCpusNotSupported import NumVirtualCpusNotSupported as NumVirtualCpusNotSupported
from .OperationDisabledByGuest import OperationDisabledByGuest as OperationDisabledByGuest
from .OperationDisallowedOnHost import OperationDisallowedOnHost as OperationDisallowedOnHost
from .OperationNotSupportedByGuest import OperationNotSupportedByGuest as OperationNotSupportedByGuest
from .OutOfBounds import OutOfBounds as OutOfBounds
from .OvfAttribute import OvfAttribute as OvfAttribute
from .OvfConnectedDevice import OvfConnectedDevice as OvfConnectedDevice
from .OvfConnectedDeviceFloppy import OvfConnectedDeviceFloppy as OvfConnectedDeviceFloppy
from .OvfConnectedDeviceIso import OvfConnectedDeviceIso as OvfConnectedDeviceIso
from .OvfConstraint import OvfConstraint as OvfConstraint
from .OvfConsumerCallbackFault import OvfConsumerCallbackFault as OvfConsumerCallbackFault
from .OvfConsumerCommunicationError import OvfConsumerCommunicationError as OvfConsumerCommunicationError
from .OvfConsumerFault import OvfConsumerFault as OvfConsumerFault
from .OvfConsumerInvalidSection import OvfConsumerInvalidSection as OvfConsumerInvalidSection
from .OvfConsumerPowerOnFault import OvfConsumerPowerOnFault as OvfConsumerPowerOnFault
from .OvfConsumerUndeclaredSection import OvfConsumerUndeclaredSection as OvfConsumerUndeclaredSection
from .OvfConsumerUndefinedPrefix import OvfConsumerUndefinedPrefix as OvfConsumerUndefinedPrefix
from .OvfConsumerValidationFault import OvfConsumerValidationFault as OvfConsumerValidationFault
from .OvfCpuCompatibility import OvfCpuCompatibility as OvfCpuCompatibility
from .OvfCpuCompatibilityCheckNotSupported import OvfCpuCompatibilityCheckNotSupported as OvfCpuCompatibilityCheckNotSupported
from .OvfDiskMappingNotFound import OvfDiskMappingNotFound as OvfDiskMappingNotFound
from .OvfDiskOrderConstraint import OvfDiskOrderConstraint as OvfDiskOrderConstraint
from .OvfDuplicateElement import OvfDuplicateElement as OvfDuplicateElement
from .OvfDuplicatedElementBoundary import OvfDuplicatedElementBoundary as OvfDuplicatedElementBoundary
from .OvfDuplicatedPropertyIdExport import OvfDuplicatedPropertyIdExport as OvfDuplicatedPropertyIdExport
from .OvfDuplicatedPropertyIdImport import OvfDuplicatedPropertyIdImport as OvfDuplicatedPropertyIdImport
from .OvfElement import OvfElement as OvfElement
from .OvfElementInvalidValue import OvfElementInvalidValue as OvfElementInvalidValue
from .OvfExport import OvfExport as OvfExport
from .OvfExportFailed import OvfExportFailed as OvfExportFailed
from .OvfFault import OvfFault as OvfFault
from .OvfHardwareCheck import OvfHardwareCheck as OvfHardwareCheck
from .OvfHardwareExport import OvfHardwareExport as OvfHardwareExport
from .OvfHostResourceConstraint import OvfHostResourceConstraint as OvfHostResourceConstraint
from .OvfHostValueNotParsed import OvfHostValueNotParsed as OvfHostValueNotParsed
from .OvfImport import OvfImport as OvfImport
from .OvfImportFailed import OvfImportFailed as OvfImportFailed
from .OvfInternalError import OvfInternalError as OvfInternalError
from .OvfInvalidPackage import OvfInvalidPackage as OvfInvalidPackage
from .OvfInvalidValue import OvfInvalidValue as OvfInvalidValue
from .OvfInvalidValueConfiguration import OvfInvalidValueConfiguration as OvfInvalidValueConfiguration
from .OvfInvalidValueEmpty import OvfInvalidValueEmpty as OvfInvalidValueEmpty
from .OvfInvalidValueFormatMalformed import OvfInvalidValueFormatMalformed as OvfInvalidValueFormatMalformed
from .OvfInvalidValueReference import OvfInvalidValueReference as OvfInvalidValueReference
from .OvfInvalidVmName import OvfInvalidVmName as OvfInvalidVmName
from .OvfMappedOsId import OvfMappedOsId as OvfMappedOsId
from .OvfMissingAttribute import OvfMissingAttribute as OvfMissingAttribute
from .OvfMissingElement import OvfMissingElement as OvfMissingElement
from .OvfMissingElementNormalBoundary import OvfMissingElementNormalBoundary as OvfMissingElementNormalBoundary
from .OvfMissingHardware import OvfMissingHardware as OvfMissingHardware
from .OvfNetworkMappingNotSupported import OvfNetworkMappingNotSupported as OvfNetworkMappingNotSupported
from .OvfNoHostNic import OvfNoHostNic as OvfNoHostNic
from .OvfNoSpaceOnController import OvfNoSpaceOnController as OvfNoSpaceOnController
from .OvfNoSupportedHardwareFamily import OvfNoSupportedHardwareFamily as OvfNoSupportedHardwareFamily
from .OvfProperty import OvfProperty as OvfProperty
from .OvfPropertyExport import OvfPropertyExport as OvfPropertyExport
from .OvfPropertyNetwork import OvfPropertyNetwork as OvfPropertyNetwork
from .OvfPropertyNetworkExport import OvfPropertyNetworkExport as OvfPropertyNetworkExport
from .OvfPropertyQualifier import OvfPropertyQualifier as OvfPropertyQualifier
from .OvfPropertyQualifierDuplicate import OvfPropertyQualifierDuplicate as OvfPropertyQualifierDuplicate
from .OvfPropertyQualifierIgnored import OvfPropertyQualifierIgnored as OvfPropertyQualifierIgnored
from .OvfPropertyType import OvfPropertyType as OvfPropertyType
from .OvfPropertyValue import OvfPropertyValue as OvfPropertyValue
from .OvfSystemFault import OvfSystemFault as OvfSystemFault
from .OvfToXmlUnsupportedElement import OvfToXmlUnsupportedElement as OvfToXmlUnsupportedElement
from .OvfUnableToExportDisk import OvfUnableToExportDisk as OvfUnableToExportDisk
from .OvfUnexpectedElement import OvfUnexpectedElement as OvfUnexpectedElement
from .OvfUnknownDevice import OvfUnknownDevice as OvfUnknownDevice
from .OvfUnknownDeviceBacking import OvfUnknownDeviceBacking as OvfUnknownDeviceBacking
from .OvfUnknownEntity import OvfUnknownEntity as OvfUnknownEntity
from .OvfUnsupportedAttribute import OvfUnsupportedAttribute as OvfUnsupportedAttribute
from .OvfUnsupportedAttributeValue import OvfUnsupportedAttributeValue as OvfUnsupportedAttributeValue
from .OvfUnsupportedDeviceBackingInfo import OvfUnsupportedDeviceBackingInfo as OvfUnsupportedDeviceBackingInfo
from .OvfUnsupportedDeviceBackingOption import OvfUnsupportedDeviceBackingOption as OvfUnsupportedDeviceBackingOption
from .OvfUnsupportedDeviceExport import OvfUnsupportedDeviceExport as OvfUnsupportedDeviceExport
from .OvfUnsupportedDiskProvisioning import OvfUnsupportedDiskProvisioning as OvfUnsupportedDiskProvisioning
from .OvfUnsupportedElement import OvfUnsupportedElement as OvfUnsupportedElement
from .OvfUnsupportedElementValue import OvfUnsupportedElementValue as OvfUnsupportedElementValue
from .OvfUnsupportedPackage import OvfUnsupportedPackage as OvfUnsupportedPackage
from .OvfUnsupportedSection import OvfUnsupportedSection as OvfUnsupportedSection
from .OvfUnsupportedSubType import OvfUnsupportedSubType as OvfUnsupportedSubType
from .OvfUnsupportedType import OvfUnsupportedType as OvfUnsupportedType
from .OvfWrongElement import OvfWrongElement as OvfWrongElement
from .OvfWrongNamespace import OvfWrongNamespace as OvfWrongNamespace
from .OvfXmlFormat import OvfXmlFormat as OvfXmlFormat
from .PasswordExpired import PasswordExpired as PasswordExpired
from .PatchAlreadyInstalled import PatchAlreadyInstalled as PatchAlreadyInstalled
from .PatchBinariesNotFound import PatchBinariesNotFound as PatchBinariesNotFound
from .PatchInstallFailed import PatchInstallFailed as PatchInstallFailed
from .PatchIntegrityError import PatchIntegrityError as PatchIntegrityError
from .PatchMetadataCorrupted import PatchMetadataCorrupted as PatchMetadataCorrupted
from .PatchMetadataInvalid import PatchMetadataInvalid as PatchMetadataInvalid
from .PatchMetadataNotFound import PatchMetadataNotFound as PatchMetadataNotFound
from .PatchMissingDependencies import PatchMissingDependencies as PatchMissingDependencies
from .PatchNotApplicable import PatchNotApplicable as PatchNotApplicable
from .PatchSuperseded import PatchSuperseded as PatchSuperseded
from .PhysCompatRDMNotSupported import PhysCompatRDMNotSupported as PhysCompatRDMNotSupported
from .PlatformConfigFault import PlatformConfigFault as PlatformConfigFault
from .PowerOnFtSecondaryFailed import PowerOnFtSecondaryFailed as PowerOnFtSecondaryFailed
from .PowerOnFtSecondaryTimedout import PowerOnFtSecondaryTimedout as PowerOnFtSecondaryTimedout
from .ProfileUpdateFailed import ProfileUpdateFailed as ProfileUpdateFailed
from .QuarantineModeFault import QuarantineModeFault as QuarantineModeFault
from .QuestionPending import QuestionPending as QuestionPending
from .QuiesceDatastoreIOForHAFailed import QuiesceDatastoreIOForHAFailed as QuiesceDatastoreIOForHAFailed
from .RDMConversionNotSupported import RDMConversionNotSupported as RDMConversionNotSupported
from .RDMNotPreserved import RDMNotPreserved as RDMNotPreserved
from .RDMNotSupported import RDMNotSupported as RDMNotSupported
from .RDMNotSupportedOnDatastore import RDMNotSupportedOnDatastore as RDMNotSupportedOnDatastore
from .RDMPointsToInaccessibleDisk import RDMPointsToInaccessibleDisk as RDMPointsToInaccessibleDisk
from .RawDiskNotSupported import RawDiskNotSupported as RawDiskNotSupported
from .ReadHostResourcePoolTreeFailed import ReadHostResourcePoolTreeFailed as ReadHostResourcePoolTreeFailed
from .ReadOnlyDisksWithLegacyDestination import ReadOnlyDisksWithLegacyDestination as ReadOnlyDisksWithLegacyDestination
from .RebootRequired import RebootRequired as RebootRequired
from .RecordReplayDisabled import RecordReplayDisabled as RecordReplayDisabled
from .RemoteDeviceNotSupported import RemoteDeviceNotSupported as RemoteDeviceNotSupported
from .RemoveFailed import RemoveFailed as RemoveFailed
from .ReplicationConfigFault import ReplicationConfigFault as ReplicationConfigFault
from .ReplicationDiskConfigFault import ReplicationDiskConfigFault as ReplicationDiskConfigFault
from .ReplicationFault import ReplicationFault as ReplicationFault
from .ReplicationIncompatibleWithFT import ReplicationIncompatibleWithFT as ReplicationIncompatibleWithFT
from .ReplicationInvalidOptions import ReplicationInvalidOptions as ReplicationInvalidOptions
from .ReplicationNotSupportedOnHost import ReplicationNotSupportedOnHost as ReplicationNotSupportedOnHost
from .ReplicationVmConfigFault import ReplicationVmConfigFault as ReplicationVmConfigFault
from .ReplicationVmFault import ReplicationVmFault as ReplicationVmFault
from .ReplicationVmInProgressFault import ReplicationVmInProgressFault as ReplicationVmInProgressFault
from .ResourceInUse import ResourceInUse as ResourceInUse
from .ResourceNotAvailable import ResourceNotAvailable as ResourceNotAvailable
from .RestrictedByAdministrator import RestrictedByAdministrator as RestrictedByAdministrator
from .RestrictedVersion import RestrictedVersion as RestrictedVersion
from .RollbackFailure import RollbackFailure as RollbackFailure
from .RuleViolation import RuleViolation as RuleViolation
from .SSLDisabledFault import SSLDisabledFault as SSLDisabledFault
from .SSLVerifyFault import SSLVerifyFault as SSLVerifyFault
from .SSPIChallenge import SSPIChallenge as SSPIChallenge
from .SecondaryVmAlreadyDisabled import SecondaryVmAlreadyDisabled as SecondaryVmAlreadyDisabled
from .SecondaryVmAlreadyEnabled import SecondaryVmAlreadyEnabled as SecondaryVmAlreadyEnabled
from .SecondaryVmAlreadyRegistered import SecondaryVmAlreadyRegistered as SecondaryVmAlreadyRegistered
from .SecondaryVmNotRegistered import SecondaryVmNotRegistered as SecondaryVmNotRegistered
from .SharedBusControllerNotSupported import SharedBusControllerNotSupported as SharedBusControllerNotSupported
from .ShrinkDiskFault import ShrinkDiskFault as ShrinkDiskFault
from .SnapshotCloneNotSupported import SnapshotCloneNotSupported as SnapshotCloneNotSupported
from .SnapshotCopyNotSupported import SnapshotCopyNotSupported as SnapshotCopyNotSupported
from .SnapshotDisabled import SnapshotDisabled as SnapshotDisabled
from .SnapshotFault import SnapshotFault as SnapshotFault
from .SnapshotIncompatibleDeviceInVm import SnapshotIncompatibleDeviceInVm as SnapshotIncompatibleDeviceInVm
from .SnapshotLocked import SnapshotLocked as SnapshotLocked
from .SnapshotMoveFromNonHomeNotSupported import SnapshotMoveFromNonHomeNotSupported as SnapshotMoveFromNonHomeNotSupported
from .SnapshotMoveNotSupported import SnapshotMoveNotSupported as SnapshotMoveNotSupported
from .SnapshotMoveToNonHomeNotSupported import SnapshotMoveToNonHomeNotSupported as SnapshotMoveToNonHomeNotSupported
from .SnapshotNoChange import SnapshotNoChange as SnapshotNoChange
from .SnapshotRevertIssue import SnapshotRevertIssue as SnapshotRevertIssue
from .SoftRuleVioCorrectionDisallowed import SoftRuleVioCorrectionDisallowed as SoftRuleVioCorrectionDisallowed
from .SoftRuleVioCorrectionImpact import SoftRuleVioCorrectionImpact as SoftRuleVioCorrectionImpact
from .SolutionUserRequired import SolutionUserRequired as SolutionUserRequired
from .SsdDiskNotAvailable import SsdDiskNotAvailable as SsdDiskNotAvailable
from .StorageDrsCannotMoveDiskInMultiWriterMode import StorageDrsCannotMoveDiskInMultiWriterMode as StorageDrsCannotMoveDiskInMultiWriterMode
from .StorageDrsCannotMoveFTVm import StorageDrsCannotMoveFTVm as StorageDrsCannotMoveFTVm
from .StorageDrsCannotMoveIndependentDisk import StorageDrsCannotMoveIndependentDisk as StorageDrsCannotMoveIndependentDisk
from .StorageDrsCannotMoveManuallyPlacedSwapFile import StorageDrsCannotMoveManuallyPlacedSwapFile as StorageDrsCannotMoveManuallyPlacedSwapFile
from .StorageDrsCannotMoveManuallyPlacedVm import StorageDrsCannotMoveManuallyPlacedVm as StorageDrsCannotMoveManuallyPlacedVm
from .StorageDrsCannotMoveSharedDisk import StorageDrsCannotMoveSharedDisk as StorageDrsCannotMoveSharedDisk
from .StorageDrsCannotMoveTemplate import StorageDrsCannotMoveTemplate as StorageDrsCannotMoveTemplate
from .StorageDrsCannotMoveVmInUserFolder import StorageDrsCannotMoveVmInUserFolder as StorageDrsCannotMoveVmInUserFolder
from .StorageDrsCannotMoveVmWithMountedCDROM import StorageDrsCannotMoveVmWithMountedCDROM as StorageDrsCannotMoveVmWithMountedCDROM
from .StorageDrsCannotMoveVmWithNoFilesInLayout import StorageDrsCannotMoveVmWithNoFilesInLayout as StorageDrsCannotMoveVmWithNoFilesInLayout
from .StorageDrsDatacentersCannotShareDatastore import StorageDrsDatacentersCannotShareDatastore as StorageDrsDatacentersCannotShareDatastore
from .StorageDrsDisabledOnVm import StorageDrsDisabledOnVm as StorageDrsDisabledOnVm
from .StorageDrsHbrDiskNotMovable import StorageDrsHbrDiskNotMovable as StorageDrsHbrDiskNotMovable
from .StorageDrsHmsMoveInProgress import StorageDrsHmsMoveInProgress as StorageDrsHmsMoveInProgress
from .StorageDrsHmsUnreachable import StorageDrsHmsUnreachable as StorageDrsHmsUnreachable
from .StorageDrsIolbDisabledInternally import StorageDrsIolbDisabledInternally as StorageDrsIolbDisabledInternally
from .StorageDrsRelocateDisabled import StorageDrsRelocateDisabled as StorageDrsRelocateDisabled
from .StorageDrsStaleHmsCollection import StorageDrsStaleHmsCollection as StorageDrsStaleHmsCollection
from .StorageDrsUnableToMoveFiles import StorageDrsUnableToMoveFiles as StorageDrsUnableToMoveFiles
from .StorageVMotionNotSupported import StorageVMotionNotSupported as StorageVMotionNotSupported
from .StorageVmotionIncompatible import StorageVmotionIncompatible as StorageVmotionIncompatible
from .SuspendedRelocateNotSupported import SuspendedRelocateNotSupported as SuspendedRelocateNotSupported
from .SwapDatastoreNotWritableOnHost import SwapDatastoreNotWritableOnHost as SwapDatastoreNotWritableOnHost
from .SwapDatastoreUnset import SwapDatastoreUnset as SwapDatastoreUnset
from .SwapPlacementOverrideNotSupported import SwapPlacementOverrideNotSupported as SwapPlacementOverrideNotSupported
from .SwitchIpUnset import SwitchIpUnset as SwitchIpUnset
from .SwitchNotInUpgradeMode import SwitchNotInUpgradeMode as SwitchNotInUpgradeMode
from .TaskInProgress import TaskInProgress as TaskInProgress
from .ThirdPartyLicenseAssignmentFailed import ThirdPartyLicenseAssignmentFailed as ThirdPartyLicenseAssignmentFailed
from .Timedout import Timedout as Timedout
from .TooManyConcurrentNativeClones import TooManyConcurrentNativeClones as TooManyConcurrentNativeClones
from .TooManyConsecutiveOverrides import TooManyConsecutiveOverrides as TooManyConsecutiveOverrides
from .TooManyDevices import TooManyDevices as TooManyDevices
from .TooManyDisksOnLegacyHost import TooManyDisksOnLegacyHost as TooManyDisksOnLegacyHost
from .TooManyGuestLogons import TooManyGuestLogons as TooManyGuestLogons
from .TooManyHosts import TooManyHosts as TooManyHosts
from .TooManyNativeCloneLevels import TooManyNativeCloneLevels as TooManyNativeCloneLevels
from .TooManyNativeClonesOnFile import TooManyNativeClonesOnFile as TooManyNativeClonesOnFile
from .TooManySnapshotLevels import TooManySnapshotLevels as TooManySnapshotLevels
from .ToolsAlreadyUpgraded import ToolsAlreadyUpgraded as ToolsAlreadyUpgraded
from .ToolsAutoUpgradeNotSupported import ToolsAutoUpgradeNotSupported as ToolsAutoUpgradeNotSupported
from .ToolsImageCopyFailed import ToolsImageCopyFailed as ToolsImageCopyFailed
from .ToolsImageNotAvailable import ToolsImageNotAvailable as ToolsImageNotAvailable
from .ToolsImageSignatureCheckFailed import ToolsImageSignatureCheckFailed as ToolsImageSignatureCheckFailed
from .ToolsInstallationInProgress import ToolsInstallationInProgress as ToolsInstallationInProgress
from .ToolsUnavailable import ToolsUnavailable as ToolsUnavailable
from .ToolsUpgradeCancelled import ToolsUpgradeCancelled as ToolsUpgradeCancelled
from .UnSupportedDatastoreForVFlash import UnSupportedDatastoreForVFlash as UnSupportedDatastoreForVFlash
from .UncommittedUndoableDisk import UncommittedUndoableDisk as UncommittedUndoableDisk
from .UnconfiguredPropertyValue import UnconfiguredPropertyValue as UnconfiguredPropertyValue
from .UncustomizableGuest import UncustomizableGuest as UncustomizableGuest
from .UnexpectedCustomizationFault import UnexpectedCustomizationFault as UnexpectedCustomizationFault
from .UnrecognizedHost import UnrecognizedHost as UnrecognizedHost
from .UnsharedSwapVMotionNotSupported import UnsharedSwapVMotionNotSupported as UnsharedSwapVMotionNotSupported
from .UnsupportedDatastore import UnsupportedDatastore as UnsupportedDatastore
from .UnsupportedGuest import UnsupportedGuest as UnsupportedGuest
from .UnsupportedVimApiVersion import UnsupportedVimApiVersion as UnsupportedVimApiVersion
from .UnsupportedVmxLocation import UnsupportedVmxLocation as UnsupportedVmxLocation
from .UnusedVirtualDiskBlocksNotScrubbed import UnusedVirtualDiskBlocksNotScrubbed as UnusedVirtualDiskBlocksNotScrubbed
from .UserNotFound import UserNotFound as UserNotFound
from .VAppConfigFault import VAppConfigFault as VAppConfigFault
from .VAppNotRunning import VAppNotRunning as VAppNotRunning
from .VAppOperationInProgress import VAppOperationInProgress as VAppOperationInProgress
from .VAppPropertyFault import VAppPropertyFault as VAppPropertyFault
from .VAppTaskInProgress import VAppTaskInProgress as VAppTaskInProgress
from .VFlashCacheHotConfigNotSupported import VFlashCacheHotConfigNotSupported as VFlashCacheHotConfigNotSupported
from .VFlashModuleNotSupported import VFlashModuleNotSupported as VFlashModuleNotSupported
from .VFlashModuleVersionIncompatible import VFlashModuleVersionIncompatible as VFlashModuleVersionIncompatible
from .VMINotSupported import VMINotSupported as VMINotSupported
from .VMOnConflictDVPort import VMOnConflictDVPort as VMOnConflictDVPort
from .VMOnVirtualIntranet import VMOnVirtualIntranet as VMOnVirtualIntranet
from .VMotionAcrossNetworkNotSupported import VMotionAcrossNetworkNotSupported as VMotionAcrossNetworkNotSupported
from .VMotionInterfaceIssue import VMotionInterfaceIssue as VMotionInterfaceIssue
from .VMotionLinkCapacityLow import VMotionLinkCapacityLow as VMotionLinkCapacityLow
from .VMotionLinkDown import VMotionLinkDown as VMotionLinkDown
from .VMotionNotConfigured import VMotionNotConfigured as VMotionNotConfigured
from .VMotionNotLicensed import VMotionNotLicensed as VMotionNotLicensed
from .VMotionNotSupported import VMotionNotSupported as VMotionNotSupported
from .VMotionProtocolIncompatible import VMotionProtocolIncompatible as VMotionProtocolIncompatible
from .VimFault import VimFault as VimFault
from .VirtualDiskBlocksNotFullyProvisioned import VirtualDiskBlocksNotFullyProvisioned as VirtualDiskBlocksNotFullyProvisioned
from .VirtualDiskModeNotSupported import VirtualDiskModeNotSupported as VirtualDiskModeNotSupported
from .VirtualEthernetCardNotSupported import VirtualEthernetCardNotSupported as VirtualEthernetCardNotSupported
from .VirtualHardwareCompatibilityIssue import VirtualHardwareCompatibilityIssue as VirtualHardwareCompatibilityIssue
from .VirtualHardwareVersionNotSupported import VirtualHardwareVersionNotSupported as VirtualHardwareVersionNotSupported
from .VmAlreadyExistsInDatacenter import VmAlreadyExistsInDatacenter as VmAlreadyExistsInDatacenter
from .VmConfigFault import VmConfigFault as VmConfigFault
from .VmConfigIncompatibleForFaultTolerance import VmConfigIncompatibleForFaultTolerance as VmConfigIncompatibleForFaultTolerance
from .VmConfigIncompatibleForRecordReplay import VmConfigIncompatibleForRecordReplay as VmConfigIncompatibleForRecordReplay
from .VmFaultToleranceConfigIssue import VmFaultToleranceConfigIssue as VmFaultToleranceConfigIssue
from .VmFaultToleranceConfigIssueWrapper import VmFaultToleranceConfigIssueWrapper as VmFaultToleranceConfigIssueWrapper
from .VmFaultToleranceInvalidFileBacking import VmFaultToleranceInvalidFileBacking as VmFaultToleranceInvalidFileBacking
from .VmFaultToleranceIssue import VmFaultToleranceIssue as VmFaultToleranceIssue
from .VmFaultToleranceOpIssuesList import VmFaultToleranceOpIssuesList as VmFaultToleranceOpIssuesList
from .VmFaultToleranceTooManyFtVcpusOnHost import VmFaultToleranceTooManyFtVcpusOnHost as VmFaultToleranceTooManyFtVcpusOnHost
from .VmFaultToleranceTooManyVMsOnHost import VmFaultToleranceTooManyVMsOnHost as VmFaultToleranceTooManyVMsOnHost
from .VmHostAffinityRuleViolation import VmHostAffinityRuleViolation as VmHostAffinityRuleViolation
from .VmLimitLicense import VmLimitLicense as VmLimitLicense
from .VmMetadataManagerFault import VmMetadataManagerFault as VmMetadataManagerFault
from .VmMonitorIncompatibleForFaultTolerance import VmMonitorIncompatibleForFaultTolerance as VmMonitorIncompatibleForFaultTolerance
from .VmPowerOnDisabled import VmPowerOnDisabled as VmPowerOnDisabled
from .VmSmpFaultToleranceTooManyVMsOnHost import VmSmpFaultToleranceTooManyVMsOnHost as VmSmpFaultToleranceTooManyVMsOnHost
from .VmToolsUpgradeFault import VmToolsUpgradeFault as VmToolsUpgradeFault
from .VmValidateMaxDevice import VmValidateMaxDevice as VmValidateMaxDevice
from .VmWwnConflict import VmWwnConflict as VmWwnConflict
from .VmfsAlreadyMounted import VmfsAlreadyMounted as VmfsAlreadyMounted
from .VmfsAmbiguousMount import VmfsAmbiguousMount as VmfsAmbiguousMount
from .VmfsMountFault import VmfsMountFault as VmfsMountFault
from .VmotionInterfaceNotEnabled import VmotionInterfaceNotEnabled as VmotionInterfaceNotEnabled
from .VolumeEditorError import VolumeEditorError as VolumeEditorError
from .VramLimitLicense import VramLimitLicense as VramLimitLicense
from .VsanClusterUuidMismatch import VsanClusterUuidMismatch as VsanClusterUuidMismatch
from .VsanDiskFault import VsanDiskFault as VsanDiskFault
from .VsanFault import VsanFault as VsanFault
from .VsanIncompatibleDiskMapping import VsanIncompatibleDiskMapping as VsanIncompatibleDiskMapping
from .VsanNodeNotMaster import VsanNodeNotMaster as VsanNodeNotMaster
from .VsanSslVerifyCertFault import VsanSslVerifyCertFault as VsanSslVerifyCertFault
from .VspanDestPortConflict import VspanDestPortConflict as VspanDestPortConflict
from .VspanPortConflict import VspanPortConflict as VspanPortConflict
from .VspanPortMoveFault import VspanPortMoveFault as VspanPortMoveFault
from .VspanPortPromiscChangeFault import VspanPortPromiscChangeFault as VspanPortPromiscChangeFault
from .VspanPortgroupPromiscChangeFault import VspanPortgroupPromiscChangeFault as VspanPortgroupPromiscChangeFault
from .VspanPortgroupTypeChangeFault import VspanPortgroupTypeChangeFault as VspanPortgroupTypeChangeFault
from .VspanPromiscuousPortNotSupported import VspanPromiscuousPortNotSupported as VspanPromiscuousPortNotSupported
from .VspanSameSessionPortConflict import VspanSameSessionPortConflict as VspanSameSessionPortConflict
from .WakeOnLanNotSupported import WakeOnLanNotSupported as WakeOnLanNotSupported
from .WakeOnLanNotSupportedByVmotionNIC import WakeOnLanNotSupportedByVmotionNIC as WakeOnLanNotSupportedByVmotionNIC
from .WillLoseHAProtection import WillLoseHAProtection as WillLoseHAProtection
from .WillModifyConfigCpuRequirements import WillModifyConfigCpuRequirements as WillModifyConfigCpuRequirements
from .WillResetSnapshotDirectory import WillResetSnapshotDirectory as WillResetSnapshotDirectory
from .WipeDiskFault import WipeDiskFault as WipeDiskFault



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.storage.replication import DeviceId
from pyVmomi.sms.storage.replication import ReplicaId

from pyVmomi.vim.vm.replication import FaultDomainId

class SourceGroupMemberInfo(DynamicData):
   class TargetDeviceId(DynamicData):
      domainId: FaultDomainId
      deviceId: ReplicaId

   deviceId: DeviceId
   targetId: list[TargetDeviceId] = []



# VMware vSphere Python SDK tests
#
# Copyright (c) 2008-2024 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import print_function

import tests

from pyVim import connect
from pyVmomi import vim


class VirtualMachineTests(tests.VCRTestBase):

    @tests.VCRTestBase.my_vcr.use_cassette('vm_nic_data.yaml',
                      cassette_library_dir=tests.fixtures_path,
                      record_mode='once', decode_compressed_response=True)
    def test_vm_nic_data(self):
        data = {
            'vCLS-fc35c4f3-c84c-4232-9446-e64ff2c9388c': [],
            'vCLS-8f66678f-3d69-4b58-a4c7-bae62203b573': [],
            'vCLS-32d7e67b-f3b4-485b-9685-b4b43c7f9c75': []
        }

        # see: http://python3porting.com/noconv.html
        si = connect.SmartConnect(host='vcsa',
                                  user='my_user',
                                  pwd='my_password')

        content = si.RetrieveContent()
        virtual_machines = content.viewManager.CreateContainerView(
            content.rootFolder, [vim.VirtualMachine], True)
        for virtual_machine in virtual_machines.view:
            name = virtual_machine.name
            self.assertTrue(name in data.keys())
            macs = data[name]
            if virtual_machine.guest:
                for net in virtual_machine.guest.net:
                    self.assertTrue(net.macAddress in macs)



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData

class StorageInfo(DynamicData):
   class UsageOnDatastore(DynamicData):
      datastore: Datastore
      committed: long
      uncommitted: long
      unshared: long

   perDatastoreUsage: list[UsageOnDatastore] = []
   timestamp: datetime



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import check as check
from . import customization as customization
from . import device as device
from . import guest as guest
from . import replication as replication

from .AffinityInfo import AffinityInfo as AffinityInfo
from .BaseIndependentFilterSpec import BaseIndependentFilterSpec as BaseIndependentFilterSpec
from .BootOptions import BootOptions as BootOptions
from .Capability import Capability as Capability
from .CdromInfo import CdromInfo as CdromInfo
from .CertThumbprint import CertThumbprint as CertThumbprint
from .CloneSpec import CloneSpec as CloneSpec
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigOption import ConfigOption as ConfigOption
from .ConfigOptionDescriptor import ConfigOptionDescriptor as ConfigOptionDescriptor
from .ConfigSpec import ConfigSpec as ConfigSpec
from .ConfigTarget import ConfigTarget as ConfigTarget
from .ConsolePreferences import ConsolePreferences as ConsolePreferences
from .ContentLibraryItemInfo import ContentLibraryItemInfo as ContentLibraryItemInfo
from .DatastoreInfo import DatastoreInfo as DatastoreInfo
from .DatastoreOption import DatastoreOption as DatastoreOption
from .DefaultPowerOpInfo import DefaultPowerOpInfo as DefaultPowerOpInfo
from .DefaultProfileSpec import DefaultProfileSpec as DefaultProfileSpec
from .DefinedProfileSpec import DefinedProfileSpec as DefinedProfileSpec
from .DeviceRuntimeInfo import DeviceRuntimeInfo as DeviceRuntimeInfo
from .DiskDeviceInfo import DiskDeviceInfo as DiskDeviceInfo
from .DvxClassInfo import DvxClassInfo as DvxClassInfo
from .DynamicPassthroughInfo import DynamicPassthroughInfo as DynamicPassthroughInfo
from .EmptyIndependentFilterSpec import EmptyIndependentFilterSpec as EmptyIndependentFilterSpec
from .EmptyProfileSpec import EmptyProfileSpec as EmptyProfileSpec
from .FaultToleranceConfigInfo import FaultToleranceConfigInfo as FaultToleranceConfigInfo
from .FaultToleranceConfigSpec import FaultToleranceConfigSpec as FaultToleranceConfigSpec
from .FaultToleranceMetaSpec import FaultToleranceMetaSpec as FaultToleranceMetaSpec
from .FaultTolerancePrimaryConfigInfo import FaultTolerancePrimaryConfigInfo as FaultTolerancePrimaryConfigInfo
from .FaultToleranceSecondaryConfigInfo import FaultToleranceSecondaryConfigInfo as FaultToleranceSecondaryConfigInfo
from .FaultToleranceSecondaryOpResult import FaultToleranceSecondaryOpResult as FaultToleranceSecondaryOpResult
from .FaultToleranceVMConfigSpec import FaultToleranceVMConfigSpec as FaultToleranceVMConfigSpec
from .FeatureRequirement import FeatureRequirement as FeatureRequirement
from .FileInfo import FileInfo as FileInfo
from .FileLayout import FileLayout as FileLayout
from .FileLayoutEx import FileLayoutEx as FileLayoutEx
from .FlagInfo import FlagInfo as FlagInfo
from .FloppyInfo import FloppyInfo as FloppyInfo
from .ForkConfigInfo import ForkConfigInfo as ForkConfigInfo
from .GuestCustomizationManager import GuestCustomizationManager as GuestCustomizationManager
from .GuestInfo import GuestInfo as GuestInfo
from .GuestIntegrityInfo import GuestIntegrityInfo as GuestIntegrityInfo
from .GuestMonitoringModeInfo import GuestMonitoringModeInfo as GuestMonitoringModeInfo
from .GuestOsDescriptor import GuestOsDescriptor as GuestOsDescriptor
from .GuestQuiesceSpec import GuestQuiesceSpec as GuestQuiesceSpec
from .IdeDiskDeviceInfo import IdeDiskDeviceInfo as IdeDiskDeviceInfo
from .IndependentFilterSpec import IndependentFilterSpec as IndependentFilterSpec
from .InstantCloneSpec import InstantCloneSpec as InstantCloneSpec
from .LegacyNetworkSwitchInfo import LegacyNetworkSwitchInfo as LegacyNetworkSwitchInfo
from .Message import Message as Message
from .NetworkInfo import NetworkInfo as NetworkInfo
from .NetworkShaperInfo import NetworkShaperInfo as NetworkShaperInfo
from .OpaqueNetworkInfo import OpaqueNetworkInfo as OpaqueNetworkInfo
from .ParallelInfo import ParallelInfo as ParallelInfo
from .PciPassthroughInfo import PciPassthroughInfo as PciPassthroughInfo
from .PciSharedGpuPassthroughInfo import PciSharedGpuPassthroughInfo as PciSharedGpuPassthroughInfo
from .PrecisionClockInfo import PrecisionClockInfo as PrecisionClockInfo
from .ProfileDetails import ProfileDetails as ProfileDetails
from .ProfileRawData import ProfileRawData as ProfileRawData
from .ProfileSpec import ProfileSpec as ProfileSpec
from .PropertyRelation import PropertyRelation as PropertyRelation
from .QuestionInfo import QuestionInfo as QuestionInfo
from .RelocateSpec import RelocateSpec as RelocateSpec
from .ReplicationConfigSpec import ReplicationConfigSpec as ReplicationConfigSpec
from .RuntimeInfo import RuntimeInfo as RuntimeInfo
from .ScheduledHardwareUpgradeInfo import ScheduledHardwareUpgradeInfo as ScheduledHardwareUpgradeInfo
from .ScsiDiskDeviceInfo import ScsiDiskDeviceInfo as ScsiDiskDeviceInfo
from .ScsiPassthroughInfo import ScsiPassthroughInfo as ScsiPassthroughInfo
from .SerialInfo import SerialInfo as SerialInfo
from .SgxInfo import SgxInfo as SgxInfo
from .SgxTargetInfo import SgxTargetInfo as SgxTargetInfo
from .Snapshot import Snapshot as Snapshot
from .SnapshotInfo import SnapshotInfo as SnapshotInfo
from .SnapshotSelectionSpec import SnapshotSelectionSpec as SnapshotSelectionSpec
from .SnapshotTree import SnapshotTree as SnapshotTree
from .SoundInfo import SoundInfo as SoundInfo
from .SriovDevicePoolInfo import SriovDevicePoolInfo as SriovDevicePoolInfo
from .SriovInfo import SriovInfo as SriovInfo
from .SriovNetworkDevicePoolInfo import SriovNetworkDevicePoolInfo as SriovNetworkDevicePoolInfo
from .StorageInfo import StorageInfo as StorageInfo
from .SubnetInfo import SubnetInfo as SubnetInfo
from .Summary import Summary as Summary
from .TargetInfo import TargetInfo as TargetInfo
from .ToolsConfigInfo import ToolsConfigInfo as ToolsConfigInfo
from .UsbInfo import UsbInfo as UsbInfo
from .UsbScanCodeSpec import UsbScanCodeSpec as UsbScanCodeSpec
from .VFlashModuleInfo import VFlashModuleInfo as VFlashModuleInfo
from .VMotionStunTimeInfo import VMotionStunTimeInfo as VMotionStunTimeInfo
from .VcpuConfig import VcpuConfig as VcpuConfig
from .VendorDeviceGroupInfo import VendorDeviceGroupInfo as VendorDeviceGroupInfo
from .VgpuDeviceInfo import VgpuDeviceInfo as VgpuDeviceInfo
from .VgpuProfileInfo import VgpuProfileInfo as VgpuProfileInfo
from .VirtualDeviceGroups import VirtualDeviceGroups as VirtualDeviceGroups
from .VirtualDeviceSwap import VirtualDeviceSwap as VirtualDeviceSwap
from .VirtualHardware import VirtualHardware as VirtualHardware
from .VirtualHardwareOption import VirtualHardwareOption as VirtualHardwareOption
from .VirtualNuma import VirtualNuma as VirtualNuma
from .VirtualNumaInfo import VirtualNumaInfo as VirtualNumaInfo
from .VirtualPMem import VirtualPMem as VirtualPMem
from .VmImportSpec import VmImportSpec as VmImportSpec
from .WindowsQuiesceSpec import WindowsQuiesceSpec as WindowsQuiesceSpec



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class DasAamNodeState(DynamicData):
   class DasState(Enum):
      uninitialized: ClassVar['DasState'] = 'uninitialized'
      initialized: ClassVar['DasState'] = 'initialized'
      configuring: ClassVar['DasState'] = 'configuring'
      unconfiguring: ClassVar['DasState'] = 'unconfiguring'
      running: ClassVar['DasState'] = 'running'
      error: ClassVar['DasState'] = 'error'
      agentShutdown: ClassVar['DasState'] = 'agentShutdown'
      nodeFailed: ClassVar['DasState'] = 'nodeFailed'

   host: HostSystem
   name: str
   configState: str
   runtimeState: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AbortWipeDiskStatus import AbortWipeDiskStatus as AbortWipeDiskStatus
from .AboutInfoEx import AboutInfoEx as AboutInfoEx
from .AddStoragePoolDiskSpec import AddStoragePoolDiskSpec as AddStoragePoolDiskSpec
from .ClusterStatus import ClusterStatus as ClusterStatus
from .ComplianceDetail import ComplianceDetail as ComplianceDetail
from .ComplianceResult import ComplianceResult as ComplianceResult
from .ComplianceStatus import ComplianceStatus as ComplianceStatus
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigInfoEx import ConfigInfoEx as ConfigInfoEx
from .CreateNativeKeyProviderSpec import CreateNativeKeyProviderSpec as CreateNativeKeyProviderSpec
from .DataInTransitEncryptionInfo import DataInTransitEncryptionInfo as DataInTransitEncryptionInfo
from .DecommissionMode import DecommissionMode as DecommissionMode
from .DeleteStoragePoolDiskSpec import DeleteStoragePoolDiskSpec as DeleteStoragePoolDiskSpec
from .DiskMapInfo import DiskMapInfo as DiskMapInfo
from .DiskMapInfoEx import DiskMapInfoEx as DiskMapInfoEx
from .DiskMapResult import DiskMapResult as DiskMapResult
from .DiskMapping import DiskMapping as DiskMapping
from .DiskMappingCreationSpec import DiskMappingCreationSpec as DiskMappingCreationSpec
from .DiskResult import DiskResult as DiskResult
from .DiskResultEx import DiskResultEx as DiskResultEx
from .DrsStats import DrsStats as DrsStats
from .EncryptionInfo import EncryptionInfo as EncryptionInfo
from .EncryptionOperation import EncryptionOperation as EncryptionOperation
from .EncryptionTransitionState import EncryptionTransitionState as EncryptionTransitionState
from .HealthState import HealthState as HealthState
from .IpConfig import IpConfig as IpConfig
from .IpConfigEx import IpConfigEx as IpConfigEx
from .MembershipInfo import MembershipInfo as MembershipInfo
from .NodeState import NodeState as NodeState
from .PolicyStatus import PolicyStatus as PolicyStatus
from .PortConfigEx import PortConfigEx as PortConfigEx
from .QueryVsanDisksSpec import QueryVsanDisksSpec as QueryVsanDisksSpec
from .RemoteVsanServerClusterConfig import RemoteVsanServerClusterConfig as RemoteVsanServerClusterConfig
from .RuntimeStats import RuntimeStats as RuntimeStats
from .ServerClusterUnicastConfig import ServerClusterUnicastConfig as ServerClusterUnicastConfig
from .ServerClusterUnicastInfo import ServerClusterUnicastInfo as ServerClusterUnicastInfo
from .ServerNodeType import ServerNodeType as ServerNodeType
from .SiteAffinityInfo import SiteAffinityInfo as SiteAffinityInfo
from .StatsType import StatsType as StatsType
from .StoragePoolDisk import StoragePoolDisk as StoragePoolDisk
from .StoragePoolDiskInfo import StoragePoolDiskInfo as StoragePoolDiskInfo
from .StoragePoolDiskType import StoragePoolDiskType as StoragePoolDiskType
from .StoragePoolInfo import StoragePoolInfo as StoragePoolInfo
from .TrimDiskEntry import TrimDiskEntry as TrimDiskEntry
from .TrimDiskSpec import TrimDiskSpec as TrimDiskSpec
from .TrimDiskType import TrimDiskType as TrimDiskType
from .UpdateStoragePoolDiskSpec import UpdateStoragePoolDiskSpec as UpdateStoragePoolDiskSpec
from .VsanAssociatedObjects import VsanAssociatedObjects as VsanAssociatedObjects
from .VsanAssociatedObjectsResult import VsanAssociatedObjectsResult as VsanAssociatedObjectsResult
from .VsanComplianceQuerySpec import VsanComplianceQuerySpec as VsanComplianceQuerySpec
from .VsanComponentSyncState import VsanComponentSyncState as VsanComponentSyncState
from .VsanDirectStorage import VsanDirectStorage as VsanDirectStorage
from .VsanDiskEvacReason import VsanDiskEvacReason as VsanDiskEvacReason
from .VsanDiskInfo import VsanDiskInfo as VsanDiskInfo
from .VsanDiskManagementSystemCapability import VsanDiskManagementSystemCapability as VsanDiskManagementSystemCapability
from .VsanDiskTrimOption import VsanDiskTrimOption as VsanDiskTrimOption
from .VsanDiskType import VsanDiskType as VsanDiskType
from .VsanDiskgroupCapability import VsanDiskgroupCapability as VsanDiskgroupCapability
from .VsanHostCapability import VsanHostCapability as VsanHostCapability
from .VsanManagedDisksInfo import VsanManagedDisksInfo as VsanManagedDisksInfo
from .VsanManagedPMemInfo import VsanManagedPMemInfo as VsanManagedPMemInfo
from .VsanObjectProfileInfo import VsanObjectProfileInfo as VsanObjectProfileInfo
from .VsanObjectSyncState import VsanObjectSyncState as VsanObjectSyncState
from .VsanRuntimeInfo import VsanRuntimeInfo as VsanRuntimeInfo
from .VsanScsiDisk import VsanScsiDisk as VsanScsiDisk
from .VsanSyncingObjectQueryResult import VsanSyncingObjectQueryResult as VsanSyncingObjectQueryResult
from .VsanSyncingObjectRecoveryDetails import VsanSyncingObjectRecoveryDetails as VsanSyncingObjectRecoveryDetails
from .VsanWhatIfEvacDetail import VsanWhatIfEvacDetail as VsanWhatIfEvacDetail
from .VsanWhatIfEvacResult import VsanWhatIfEvacResult as VsanWhatIfEvacResult
from .WipeDiskEligible import WipeDiskEligible as WipeDiskEligible
from .WipeDiskState import WipeDiskState as WipeDiskState
from .WipeDiskStatus import WipeDiskStatus as WipeDiskStatus



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import IODiagnosticsObjectLayout
from pyVmomi.vim.vsan import IOLatency

class ObjectIOStats(DynamicData):
   backingObjectId: str
   ioLatencyStats: list[IOLatency] = []
   objectLayout: IODiagnosticsObjectLayout



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .BrokenDiskChainIssue import BrokenDiskChainIssue as BrokenDiskChainIssue
from .DisallowDataMovementIssue import DisallowDataMovementIssue as DisallowDataMovementIssue
from .DisallowEvacuateDataIssue import DisallowEvacuateDataIssue as DisallowEvacuateDataIssue
from .DiskUnhealthIssue import DiskUnhealthIssue as DiskUnhealthIssue
from .HigherObjectsPresentDuringDowngradeIssue import HigherObjectsPresentDuringDowngradeIssue as HigherObjectsPresentDuringDowngradeIssue
from .HostPropertyRetrieveIssue import HostPropertyRetrieveIssue as HostPropertyRetrieveIssue
from .HostWithHybridDiskgroupIssue import HostWithHybridDiskgroupIssue as HostWithHybridDiskgroupIssue
from .HostsCompressionOnlyNotSupported import HostsCompressionOnlyNotSupported as HostsCompressionOnlyNotSupported
from .MixedEsxVersionInClientIssue import MixedEsxVersionInClientIssue as MixedEsxVersionInClientIssue
from .MixedEsxVersionIssue import MixedEsxVersionIssue as MixedEsxVersionIssue
from .ObjectInaccessibleIssue import ObjectInaccessibleIssue as ObjectInaccessibleIssue
from .ObjectPolicyIssue import ObjectPolicyIssue as ObjectPolicyIssue
from .RemoteClusterNotCompatible import RemoteClusterNotCompatible as RemoteClusterNotCompatible
from .UnknownScanIssue import UnknownScanIssue as UnknownScanIssue
from .UnsupportedHighDiskVersionIssue import UnsupportedHighDiskVersionIssue as UnsupportedHighDiskVersionIssue



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Network

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import OptionValue

class OpaqueNetwork(Network):
   class Summary(Network.Summary):
      opaqueNetworkId: str
      opaqueNetworkType: str

   class Capability(DynamicData):
      networkReservationSupported: bool

   @property
   def capability(self) -> Optional[Capability]: ...
   @property
   def extraConfig(self) -> list[OptionValue]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.pbm import ServerObjectRef

from pyVmomi.pbm.placement import CompatibilityResult
from pyVmomi.pbm.placement import PlacementHub
from pyVmomi.pbm.placement import Requirement

from pyVmomi.pbm.profile import CapabilityBasedProfileCreateSpec
from pyVmomi.pbm.profile import ProfileId

class PlacementSolver(ManagedObject):
   def QueryMatchingHub(self, hubsToSearch: list[PlacementHub], profile: ProfileId) -> list[PlacementHub]: ...
   def QueryMatchingHubWithSpec(self, hubsToSearch: list[PlacementHub], createSpec: CapabilityBasedProfileCreateSpec) -> list[PlacementHub]: ...
   def CheckCompatibility(self, hubsToSearch: list[PlacementHub], profile: ProfileId) -> list[CompatibilityResult]: ...
   def CheckCompatibilityWithSpec(self, hubsToSearch: list[PlacementHub], profileSpec: CapabilityBasedProfileCreateSpec) -> list[CompatibilityResult]: ...
   def CheckRequirements(self, hubsToSearch: list[PlacementHub], placementSubjectRef: Optional[ServerObjectRef], placementSubjectRequirement: list[Requirement]) -> list[CompatibilityResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.pbm.placement import PlacementHub

from pyVmomi.pbm.profile import Profile

class DefaultProfileInfo(DynamicData):
   datastores: list[PlacementHub] = []
   defaultProfile: Optional[Profile] = None
   methodFault: Optional[MethodFault] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import ResourcePool

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import DistributedVirtualPortgroupInfo
from pyVmomi.vim.dvs import DistributedVirtualSwitchInfo

from pyVmomi.vim.vm import CdromInfo
from pyVmomi.vim.vm import DatastoreInfo
from pyVmomi.vim.vm import DvxClassInfo
from pyVmomi.vim.vm import DynamicPassthroughInfo
from pyVmomi.vim.vm import FloppyInfo
from pyVmomi.vim.vm import IdeDiskDeviceInfo
from pyVmomi.vim.vm import LegacyNetworkSwitchInfo
from pyVmomi.vim.vm import NetworkInfo
from pyVmomi.vim.vm import OpaqueNetworkInfo
from pyVmomi.vim.vm import ParallelInfo
from pyVmomi.vim.vm import PciPassthroughInfo
from pyVmomi.vim.vm import PciSharedGpuPassthroughInfo
from pyVmomi.vim.vm import PrecisionClockInfo
from pyVmomi.vim.vm import ScsiDiskDeviceInfo
from pyVmomi.vim.vm import ScsiPassthroughInfo
from pyVmomi.vim.vm import SerialInfo
from pyVmomi.vim.vm import SgxTargetInfo
from pyVmomi.vim.vm import SoundInfo
from pyVmomi.vim.vm import SriovInfo
from pyVmomi.vim.vm import SubnetInfo
from pyVmomi.vim.vm import UsbInfo
from pyVmomi.vim.vm import VFlashModuleInfo
from pyVmomi.vim.vm import VendorDeviceGroupInfo
from pyVmomi.vim.vm import VgpuDeviceInfo
from pyVmomi.vim.vm import VgpuProfileInfo

class ConfigTarget(DynamicData):
   numCpus: int
   numCpuCores: int
   numNumaNodes: int
   maxCpusPerHost: Optional[int] = None
   smcPresent: bool
   datastore: list[DatastoreInfo] = []
   network: list[NetworkInfo] = []
   opaqueNetwork: list[OpaqueNetworkInfo] = []
   distributedVirtualPortgroup: list[DistributedVirtualPortgroupInfo] = []
   distributedVirtualSwitch: list[DistributedVirtualSwitchInfo] = []
   subnetInfo: list[SubnetInfo] = []
   cdRom: list[CdromInfo] = []
   serial: list[SerialInfo] = []
   parallel: list[ParallelInfo] = []
   sound: list[SoundInfo] = []
   usb: list[UsbInfo] = []
   floppy: list[FloppyInfo] = []
   legacyNetworkInfo: list[LegacyNetworkSwitchInfo] = []
   scsiPassthrough: list[ScsiPassthroughInfo] = []
   scsiDisk: list[ScsiDiskDeviceInfo] = []
   ideDisk: list[IdeDiskDeviceInfo] = []
   maxMemMBOptimalPerf: int
   supportedMaxMemMB: Optional[int] = None
   resourcePool: Optional[ResourcePool.RuntimeInfo] = None
   autoVmotion: Optional[bool] = None
   pciPassthrough: list[PciPassthroughInfo] = []
   sriov: list[SriovInfo] = []
   vFlashModule: list[VFlashModuleInfo] = []
   sharedGpuPassthroughTypes: list[PciSharedGpuPassthroughInfo] = []
   availablePersistentMemoryReservationMB: Optional[long] = None
   dynamicPassthrough: list[DynamicPassthroughInfo] = []
   sgxTargetInfo: Optional[SgxTargetInfo] = None
   precisionClockInfo: list[PrecisionClockInfo] = []
   sevSupported: Optional[bool] = None
   vgpuDeviceInfo: list[VgpuDeviceInfo] = []
   vgpuProfileInfo: list[VgpuProfileInfo] = []
   vendorDeviceGroupInfo: list[VendorDeviceGroupInfo] = []
   maxSimultaneousThreads: Optional[int] = None
   dvxClassInfo: list[DvxClassInfo] = []
   sevSnpSupported: Optional[bool] = None
   tdxSupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.vm.guest import AliasManager
from pyVmomi.vim.vm.guest import AuthManager
from pyVmomi.vim.vm.guest import FileManager
from pyVmomi.vim.vm.guest import ProcessManager
from pyVmomi.vim.vm.guest import WindowsRegistryManager

class GuestOperationsManager(ManagedObject):
   @property
   def authManager(self) -> Optional[AuthManager]: ...
   @property
   def fileManager(self) -> Optional[FileManager]: ...
   @property
   def processManager(self) -> Optional[ProcessManager]: ...
   @property
   def guestWindowsRegistryManager(self) -> Optional[WindowsRegistryManager]: ...
   @property
   def aliasManager(self) -> Optional[AliasManager]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AccessControlSpec import AccessControlSpec as AccessControlSpec
from .AsyncQueryResult import AsyncQueryResult as AsyncQueryResult
from .BackingObjectDetails import BackingObjectDetails as BackingObjectDetails
from .BaseCreateSpec import BaseCreateSpec as BaseCreateSpec
from .BlockBackingDetails import BlockBackingDetails as BlockBackingDetails
from .BlockVolumeRelocateSpec import BlockVolumeRelocateSpec as BlockVolumeRelocateSpec
from .ClusterFlavor import ClusterFlavor as ClusterFlavor
from .ClusterType import ClusterType as ClusterType
from .ContainerCluster import ContainerCluster as ContainerCluster
from .Cursor import Cursor as Cursor
from .EntityMetadata import EntityMetadata as EntityMetadata
from .FileBackingDetails import FileBackingDetails as FileBackingDetails
from .FileCreateSpec import FileCreateSpec as FileCreateSpec
from .KubernetesEntityMetadata import KubernetesEntityMetadata as KubernetesEntityMetadata
from .KubernetesEntityReference import KubernetesEntityReference as KubernetesEntityReference
from .KubernetesEntityType import KubernetesEntityType as KubernetesEntityType
from .KubernetesQueryFilter import KubernetesQueryFilter as KubernetesQueryFilter
from .MetricFormat import MetricFormat as MetricFormat
from .MetricType import MetricType as MetricType
from .NFSAccessControlSpec import NFSAccessControlSpec as NFSAccessControlSpec
from .PlacementResult import PlacementResult as PlacementResult
from .QueryFilter import QueryFilter as QueryFilter
from .QueryResult import QueryResult as QueryResult
from .QuerySelection import QuerySelection as QuerySelection
from .QuerySelectionNameType import QuerySelectionNameType as QuerySelectionNameType
from .SnapshotCreateSpec import SnapshotCreateSpec as SnapshotCreateSpec
from .SnapshotDeleteSpec import SnapshotDeleteSpec as SnapshotDeleteSpec
from .SnapshotId import SnapshotId as SnapshotId
from .SnapshotVolumeSource import SnapshotVolumeSource as SnapshotVolumeSource
from .VSANFileCreateSpec import VSANFileCreateSpec as VSANFileCreateSpec
from .Volume import Volume as Volume
from .VolumeACLConfigureSpec import VolumeACLConfigureSpec as VolumeACLConfigureSpec
from .VolumeAttachDetachSpec import VolumeAttachDetachSpec as VolumeAttachDetachSpec
from .VolumeAttachResult import VolumeAttachResult as VolumeAttachResult
from .VolumeCreateResult import VolumeCreateResult as VolumeCreateResult
from .VolumeCreateSpec import VolumeCreateSpec as VolumeCreateSpec
from .VolumeExtendSpec import VolumeExtendSpec as VolumeExtendSpec
from .VolumeId import VolumeId as VolumeId
from .VolumeManager import VolumeManager as VolumeManager
from .VolumeMetadata import VolumeMetadata as VolumeMetadata
from .VolumeMetadataUpdateSpec import VolumeMetadataUpdateSpec as VolumeMetadataUpdateSpec
from .VolumeOperationBatchResult import VolumeOperationBatchResult as VolumeOperationBatchResult
from .VolumeOperationResult import VolumeOperationResult as VolumeOperationResult
from .VolumePolicyReconfigSpec import VolumePolicyReconfigSpec as VolumePolicyReconfigSpec
from .VolumeRelocateSpec import VolumeRelocateSpec as VolumeRelocateSpec
from .VolumeSource import VolumeSource as VolumeSource
from .VolumeType import VolumeType as VolumeType
from .VsanFileShareBackingDetails import VsanFileShareBackingDetails as VsanFileShareBackingDetails



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanHclDeviceConstraint
from pyVmomi.vim.vsan import VsanHostDeviceInfo

class VsanHclReleaseConstraint(DynamicData):
   cluster: ClusterComputeResource
   release: str
   hostDevices: list[VsanHostDeviceInfo] = []
   constraints: list[VsanHclDeviceConstraint] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VsanFileServicePreflightCheckResult(DynamicData):
   ovfInstalled: Optional[str] = None
   fsvmVersion: Optional[str] = None
   lastUpgradeDate: Optional[datetime] = None
   ovfMixedModeIssue: Optional[str] = None
   hostVersion: Optional[str] = None
   mixedModeIssue: Optional[str] = None
   networkPartitionIssue: Optional[str] = None
   vsanDatastoreIssue: Optional[str] = None
   domainConfigIssue: Optional[str] = None
   fileServiceVersion: Optional[str] = None
   dvsConfigIssue: Optional[str] = None
   domainConfigWarning: Optional[str] = None
   ntpConfigWarning: Optional[str] = None
   svsConfigIssue: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.capability import CapabilityMetadata
from pyVmomi.pbm.capability import ConstraintInstance

class CapabilityInstance(DynamicData):
   id: CapabilityMetadata.UniqueId
   constraint: list[ConstraintInstance] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.host import IpRouteConfig
from pyVmomi.vim.host import VirtualNicConnection

class IpRouteConfigSpec(IpRouteConfig):
   gatewayDeviceConnection: Optional[VirtualNicConnection] = None
   ipV6GatewayDeviceConnection: Optional[VirtualNicConnection] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class TpmAttestationInfo(DynamicData):
   class AcceptanceStatus(Enum):
      notAccepted: ClassVar['AcceptanceStatus'] = 'notAccepted'
      accepted: ClassVar['AcceptanceStatus'] = 'accepted'

   time: datetime
   status: AcceptanceStatus
   message: Optional[LocalizableMessage] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.pbm import ExtendedElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.capability import PropertyMetadata

class CapabilityMetadata(DynamicData):
   class UniqueId(DynamicData):
      namespace: str
      id: str

   id: UniqueId
   summary: ExtendedElementDescription
   mandatory: Optional[bool] = None
   hint: Optional[bool] = None
   keyId: Optional[str] = None
   allowMultipleConstraints: Optional[bool] = None
   propertyMetadata: list[PropertyMetadata] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.storage import NameValuePair

class StorageAlarm(DynamicData):
   alarmId: long
   alarmType: str
   containerId: Optional[str] = None
   objectId: Optional[str] = None
   objectType: str
   status: str
   alarmTimeStamp: datetime
   messageId: str
   parameterList: list[NameValuePair] = []
   alarmObject: Optional[object] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.profile import ProfilePropertyPath

class AnswerFileStatusResult(DynamicData):
   class AnswerFileStatusError(DynamicData):
      userInputPath: ProfilePropertyPath
      errMsg: LocalizableMessage

   checkedTime: datetime
   host: HostSystem
   status: str
   error: list[AnswerFileStatusError] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VibInfo(DynamicData):
   class SoftwareTags(DynamicData):
      tags: list[str] = []

   id: str
   name: str
   version: str
   vendor: str
   summary: str
   softwareTags: Optional[SoftwareTags] = None
   releaseDate: datetime



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import ReplicationVmFault

class ReplicationVmInProgressFault(ReplicationVmFault):
   class Activity(Enum):
      fullSync: ClassVar['Activity'] = 'fullSync'
      delta: ClassVar['Activity'] = 'delta'

   requestedActivity: str
   inProgressActivity: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import OvfImport

class OvfCpuCompatibility(OvfImport):
   registerName: str
   level: int
   registerValue: str
   desiredRegisterValue: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class ReconcileResult(DynamicData):
   class InvalidDiskPath(DynamicData):
      path: str
      reason: str

   class ReconcileDetail(DynamicData):
      hostName: Optional[str] = None
      reconcileReportPath: Optional[str] = None
      isReconciled: Optional[bool] = None
      isDeepScanned: Optional[bool] = None
      numberOfReconcileIssues: Optional[int] = None
      numberOfFcdsBeforeReconcile: Optional[int] = None
      numberOfFcdsAfterReconcile: Optional[int] = None
      invalidDiskPaths: list[InvalidDiskPath] = []

   reconcileDetails: list[ReconcileDetail] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class ProductInfo(DynamicData):
   key: int
   classId: Optional[str] = None
   instanceId: Optional[str] = None
   name: Optional[str] = None
   vendor: Optional[str] = None
   version: Optional[str] = None
   fullVersion: Optional[str] = None
   vendorUrl: Optional[str] = None
   productUrl: Optional[str] = None
   appUrl: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

class PowerSystem(ManagedObject):
   class PowerPolicy(DynamicData):
      key: int
      name: str
      shortName: str
      description: str

   class Capability(DynamicData):
      availablePolicy: list[PowerPolicy] = []

   class Info(DynamicData):
      currentPolicy: PowerPolicy

   @property
   def capability(self) -> Capability: ...
   @property
   def info(self) -> Info: ...

   def ConfigurePolicy(self, key: int) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.fault import InvalidDeviceSpec

from pyVmomi.vim.vm.device import VirtualDeviceSpec

class InvalidDeviceOperation(InvalidDeviceSpec):
   badOp: Optional[VirtualDeviceSpec.Operation] = None
   badFileOp: Optional[VirtualDeviceSpec.FileOperation] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import auth as auth
from . import fault as fault
from . import vso as vso

from .AboutInfo import AboutInfo as AboutInfo
from .QueryDatastoreInfoResult import QueryDatastoreInfoResult as QueryDatastoreInfoResult
from .ServiceInstance import ServiceInstance as ServiceInstance
from .ServiceInstanceContent import ServiceInstanceContent as ServiceInstanceContent
from .StorageLifecycleManager import StorageLifecycleManager as StorageLifecycleManager
from .Task import Task as Task
from .TaskInfo import TaskInfo as TaskInfo
from .TaskReason import TaskReason as TaskReason
from .TaskReasonAlarm import TaskReasonAlarm as TaskReasonAlarm
from .TaskReasonSchedule import TaskReasonSchedule as TaskReasonSchedule
from .TaskReasonSystem import TaskReasonSystem as TaskReasonSystem
from .TaskReasonUser import TaskReasonUser as TaskReasonUser



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class TaskInfoFilterSpec(DynamicData):
   class FilterTaskResults(DynamicData):
      removeAll: Optional[bool] = None
      descriptionIds: list[str] = []
      filterIn: Optional[bool] = None

   filterTaskResults: Optional[FilterTaskResults] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AlreadyExists import AlreadyExists as AlreadyExists
from .CapabilityProfilePropertyMismatchFault import CapabilityProfilePropertyMismatchFault as CapabilityProfilePropertyMismatchFault
from .CompatibilityCheckFault import CompatibilityCheckFault as CompatibilityCheckFault
from .DefaultProfileAppliesFault import DefaultProfileAppliesFault as DefaultProfileAppliesFault
from .DuplicateName import DuplicateName as DuplicateName
from .IncompatibleVendorSpecificRuleSet import IncompatibleVendorSpecificRuleSet as IncompatibleVendorSpecificRuleSet
from .InvalidLogin import InvalidLogin as InvalidLogin
from .LegacyHubsNotSupported import LegacyHubsNotSupported as LegacyHubsNotSupported
from .NoPermission import NoPermission as NoPermission
from .NonExistentHubs import NonExistentHubs as NonExistentHubs
from .NotFound import NotFound as NotFound
from .PBMFault import PBMFault as PBMFault
from .ProfileStorageFault import ProfileStorageFault as ProfileStorageFault
from .PropertyMismatchFault import PropertyMismatchFault as PropertyMismatchFault
from .ResourceInUse import ResourceInUse as ResourceInUse



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.pbm.profile import CapabilityConstraints
from pyVmomi.pbm.profile import Profile
from pyVmomi.pbm.profile import ResourceType

class CapabilityBasedProfile(Profile):
   class ProfileCategoryEnum(Enum):
      REQUIREMENT: ClassVar['ProfileCategoryEnum'] = 'REQUIREMENT'
      RESOURCE: ClassVar['ProfileCategoryEnum'] = 'RESOURCE'
      DATA_SERVICE_POLICY: ClassVar['ProfileCategoryEnum'] = 'DATA_SERVICE_POLICY'

   class SystemCreatedProfileType(Enum):
      VsanDefaultProfile: ClassVar['SystemCreatedProfileType'] = 'VsanDefaultProfile'
      VVolDefaultProfile: ClassVar['SystemCreatedProfileType'] = 'VVolDefaultProfile'
      PmemDefaultProfile: ClassVar['SystemCreatedProfileType'] = 'PmemDefaultProfile'
      VmcManagementProfile: ClassVar['SystemCreatedProfileType'] = 'VmcManagementProfile'
      VsanMaxDefaultProfile: ClassVar['SystemCreatedProfileType'] = 'VsanMaxDefaultProfile'

   profileCategory: str
   resourceType: ResourceType
   constraints: CapabilityConstraints
   generationId: Optional[long] = None
   isDefault: bool
   systemCreatedProfileType: Optional[str] = None
   lineOfService: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ComputeResource

from pyVmomi.vim.cluster import CryptoConfigInfo
from pyVmomi.vim.cluster import DasConfigInfo
from pyVmomi.vim.cluster import DasVmConfigInfo
from pyVmomi.vim.cluster import DpmConfigInfo
from pyVmomi.vim.cluster import DpmHostConfigInfo
from pyVmomi.vim.cluster import DrsConfigInfo
from pyVmomi.vim.cluster import DrsVmConfigInfo
from pyVmomi.vim.cluster import GroupInfo
from pyVmomi.vim.cluster import InfraUpdateHaConfigInfo
from pyVmomi.vim.cluster import OrchestrationInfo
from pyVmomi.vim.cluster import ProactiveDrsConfigInfo
from pyVmomi.vim.cluster import RuleInfo
from pyVmomi.vim.cluster import SystemVMsConfigInfo
from pyVmomi.vim.cluster import VmOrchestrationInfo

from pyVmomi.vim.vsan.cluster import ConfigInfo
from pyVmomi.vim.vsan.cluster import CoreConfigInfo

from pyVmomi.vim.vsan.host import ConfigInfo

class ConfigInfoEx(ComputeResource.ConfigInfo):
   systemVMsConfig: Optional[SystemVMsConfigInfo] = None
   dasConfig: DasConfigInfo
   dasVmConfig: list[DasVmConfigInfo] = []
   drsConfig: DrsConfigInfo
   drsVmConfig: list[DrsVmConfigInfo] = []
   rule: list[RuleInfo] = []
   orchestration: Optional[OrchestrationInfo] = None
   vmOrchestration: list[VmOrchestrationInfo] = []
   dpmConfigInfo: Optional[DpmConfigInfo] = None
   dpmHostConfig: list[DpmHostConfigInfo] = []
   vsanConfigInfo: Optional[ConfigInfo] = None
   vsanHostConfig: list[ConfigInfo] = []
   group: list[GroupInfo] = []
   infraUpdateHaConfig: Optional[InfraUpdateHaConfigInfo] = None
   proactiveDrsConfig: Optional[ProactiveDrsConfigInfo] = None
   cryptoConfig: Optional[CryptoConfigInfo] = None
   vsanCoreConfig: Optional[CoreConfigInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualNVDIMM(VirtualDevice):
   class BackingInfo(VirtualDevice.FileBackingInfo):
      parent: Optional[BackingInfo] = None
      changeId: Optional[str] = None

   capacityInMB: long
   configuredCapacityInMB: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Folder
from pyVmomi.vim import HostSystem
from pyVmomi.vim import HttpNfcLease
from pyVmomi.vim import ImportSpec
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import ResourceConfigOption
from pyVmomi.vim import ResourceConfigSpec
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualApp
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import VAppConfigSpec

from pyVmomi.vim.vm import ConfigSpec

class ResourcePool(ManagedEntity):
   class ResourceUsage(DynamicData):
      reservationUsed: long
      reservationUsedForVm: long
      unreservedForPool: long
      unreservedForVm: long
      overallUsage: long
      maxUsage: long

   class RuntimeInfo(DynamicData):
      memory: ResourceUsage
      cpu: ResourceUsage
      overallStatus: ManagedEntity.Status
      sharesScalable: Optional[str] = None

   class Summary(DynamicData):
      class QuickStats(DynamicData):
         overallCpuUsage: Optional[long] = None
         overallCpuDemand: Optional[long] = None
         guestMemoryUsage: Optional[long] = None
         hostMemoryUsage: Optional[long] = None
         distributedCpuEntitlement: Optional[long] = None
         distributedMemoryEntitlement: Optional[long] = None
         staticCpuEntitlement: Optional[int] = None
         staticMemoryEntitlement: Optional[int] = None
         privateMemory: Optional[long] = None
         sharedMemory: Optional[long] = None
         swappedMemory: Optional[long] = None
         balloonedMemory: Optional[long] = None
         overheadMemory: Optional[long] = None
         consumedOverheadMemory: Optional[long] = None
         compressedMemory: Optional[long] = None

      name: str
      config: ResourceConfigSpec
      runtime: RuntimeInfo
      quickStats: Optional[QuickStats] = None
      configuredMemoryMB: Optional[int] = None

   @property
   def summary(self) -> Summary: ...
   @property
   def runtime(self) -> RuntimeInfo: ...
   @property
   def owner(self) -> ComputeResource: ...
   @property
   def resourcePool(self) -> list[ResourcePool]: ...
   @property
   def vm(self) -> list[VirtualMachine]: ...
   @property
   def config(self) -> ResourceConfigSpec: ...
   @property
   def namespace(self) -> Optional[str]: ...
   @property
   def childConfiguration(self) -> list[ResourceConfigSpec]: ...

   def UpdateConfig(self, name: Optional[str], config: Optional[ResourceConfigSpec]) -> NoReturn: ...
   def MoveInto(self, list: list[ManagedEntity]) -> NoReturn: ...
   def UpdateChildResourceConfiguration(self, spec: list[ResourceConfigSpec]) -> NoReturn: ...
   def CreateResourcePool(self, name: str, spec: ResourceConfigSpec) -> ResourcePool: ...
   def DestroyChildren(self) -> NoReturn: ...
   def CreateVApp(self, name: str, resSpec: ResourceConfigSpec, configSpec: VAppConfigSpec, vmFolder: Optional[Folder]) -> VirtualApp: ...
   def CreateVm(self, config: ConfigSpec, host: Optional[HostSystem]) -> Task: ...
   def RegisterVm(self, path: str, name: Optional[str], host: Optional[HostSystem]) -> Task: ...
   def ImportVApp(self, spec: ImportSpec, folder: Optional[Folder], host: Optional[HostSystem]) -> HttpNfcLease: ...
   def QueryResourceConfigOption(self) -> ResourceConfigOption: ...
   def RefreshRuntime(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanUnicastAddressInfo

from pyVmomi.vim.vm import CertThumbprint

class VsanPerfMemberInfo(DynamicData):
   thumbprint: str
   thumbprintList: list[CertThumbprint] = []
   memberUuid: Optional[str] = None
   isSupportUnicast: Optional[bool] = None
   unicastAddressInfos: list[VsanUnicastAddressInfo] = []
   hostname: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .HostDiskMappingInfo import HostDiskMappingInfo as HostDiskMappingInfo
from .HostDiskMappingOption import HostDiskMappingOption as HostDiskMappingOption
from .ParaVirtualSCSIController import ParaVirtualSCSIController as ParaVirtualSCSIController
from .ParaVirtualSCSIControllerOption import ParaVirtualSCSIControllerOption as ParaVirtualSCSIControllerOption
from .VirtualAHCIController import VirtualAHCIController as VirtualAHCIController
from .VirtualAHCIControllerOption import VirtualAHCIControllerOption as VirtualAHCIControllerOption
from .VirtualBusLogicController import VirtualBusLogicController as VirtualBusLogicController
from .VirtualBusLogicControllerOption import VirtualBusLogicControllerOption as VirtualBusLogicControllerOption
from .VirtualCdrom import VirtualCdrom as VirtualCdrom
from .VirtualCdromOption import VirtualCdromOption as VirtualCdromOption
from .VirtualController import VirtualController as VirtualController
from .VirtualControllerOption import VirtualControllerOption as VirtualControllerOption
from .VirtualDevice import VirtualDevice as VirtualDevice
from .VirtualDeviceOption import VirtualDeviceOption as VirtualDeviceOption
from .VirtualDeviceSpec import VirtualDeviceSpec as VirtualDeviceSpec
from .VirtualDisk import VirtualDisk as VirtualDisk
from .VirtualDiskId import VirtualDiskId as VirtualDiskId
from .VirtualDiskOption import VirtualDiskOption as VirtualDiskOption
from .VirtualDiskSpec import VirtualDiskSpec as VirtualDiskSpec
from .VirtualE1000 import VirtualE1000 as VirtualE1000
from .VirtualE1000Option import VirtualE1000Option as VirtualE1000Option
from .VirtualE1000e import VirtualE1000e as VirtualE1000e
from .VirtualE1000eOption import VirtualE1000eOption as VirtualE1000eOption
from .VirtualEnsoniq1371 import VirtualEnsoniq1371 as VirtualEnsoniq1371
from .VirtualEnsoniq1371Option import VirtualEnsoniq1371Option as VirtualEnsoniq1371Option
from .VirtualEthernetCard import VirtualEthernetCard as VirtualEthernetCard
from .VirtualEthernetCardOption import VirtualEthernetCardOption as VirtualEthernetCardOption
from .VirtualFloppy import VirtualFloppy as VirtualFloppy
from .VirtualFloppyOption import VirtualFloppyOption as VirtualFloppyOption
from .VirtualHdAudioCard import VirtualHdAudioCard as VirtualHdAudioCard
from .VirtualHdAudioCardOption import VirtualHdAudioCardOption as VirtualHdAudioCardOption
from .VirtualIDEController import VirtualIDEController as VirtualIDEController
from .VirtualIDEControllerOption import VirtualIDEControllerOption as VirtualIDEControllerOption
from .VirtualKeyboard import VirtualKeyboard as VirtualKeyboard
from .VirtualKeyboardOption import VirtualKeyboardOption as VirtualKeyboardOption
from .VirtualLsiLogicController import VirtualLsiLogicController as VirtualLsiLogicController
from .VirtualLsiLogicControllerOption import VirtualLsiLogicControllerOption as VirtualLsiLogicControllerOption
from .VirtualLsiLogicSASController import VirtualLsiLogicSASController as VirtualLsiLogicSASController
from .VirtualLsiLogicSASControllerOption import VirtualLsiLogicSASControllerOption as VirtualLsiLogicSASControllerOption
from .VirtualNVDIMM import VirtualNVDIMM as VirtualNVDIMM
from .VirtualNVDIMMController import VirtualNVDIMMController as VirtualNVDIMMController
from .VirtualNVDIMMControllerOption import VirtualNVDIMMControllerOption as VirtualNVDIMMControllerOption
from .VirtualNVDIMMOption import VirtualNVDIMMOption as VirtualNVDIMMOption
from .VirtualNVMEController import VirtualNVMEController as VirtualNVMEController
from .VirtualNVMEControllerOption import VirtualNVMEControllerOption as VirtualNVMEControllerOption
from .VirtualPCIController import VirtualPCIController as VirtualPCIController
from .VirtualPCIControllerOption import VirtualPCIControllerOption as VirtualPCIControllerOption
from .VirtualPCIPassthrough import VirtualPCIPassthrough as VirtualPCIPassthrough
from .VirtualPCIPassthroughOption import VirtualPCIPassthroughOption as VirtualPCIPassthroughOption
from .VirtualPCNet32 import VirtualPCNet32 as VirtualPCNet32
from .VirtualPCNet32Option import VirtualPCNet32Option as VirtualPCNet32Option
from .VirtualPS2Controller import VirtualPS2Controller as VirtualPS2Controller
from .VirtualPS2ControllerOption import VirtualPS2ControllerOption as VirtualPS2ControllerOption
from .VirtualParallelPort import VirtualParallelPort as VirtualParallelPort
from .VirtualParallelPortOption import VirtualParallelPortOption as VirtualParallelPortOption
from .VirtualPointingDevice import VirtualPointingDevice as VirtualPointingDevice
from .VirtualPointingDeviceOption import VirtualPointingDeviceOption as VirtualPointingDeviceOption
from .VirtualPrecisionClock import VirtualPrecisionClock as VirtualPrecisionClock
from .VirtualPrecisionClockOption import VirtualPrecisionClockOption as VirtualPrecisionClockOption
from .VirtualSATAController import VirtualSATAController as VirtualSATAController
from .VirtualSATAControllerOption import VirtualSATAControllerOption as VirtualSATAControllerOption
from .VirtualSCSIController import VirtualSCSIController as VirtualSCSIController
from .VirtualSCSIControllerOption import VirtualSCSIControllerOption as VirtualSCSIControllerOption
from .VirtualSCSIPassthrough import VirtualSCSIPassthrough as VirtualSCSIPassthrough
from .VirtualSCSIPassthroughOption import VirtualSCSIPassthroughOption as VirtualSCSIPassthroughOption
from .VirtualSIOController import VirtualSIOController as VirtualSIOController
from .VirtualSIOControllerOption import VirtualSIOControllerOption as VirtualSIOControllerOption
from .VirtualSerialPort import VirtualSerialPort as VirtualSerialPort
from .VirtualSerialPortOption import VirtualSerialPortOption as VirtualSerialPortOption
from .VirtualSoundBlaster16 import VirtualSoundBlaster16 as VirtualSoundBlaster16
from .VirtualSoundBlaster16Option import VirtualSoundBlaster16Option as VirtualSoundBlaster16Option
from .VirtualSoundCard import VirtualSoundCard as VirtualSoundCard
from .VirtualSoundCardOption import VirtualSoundCardOption as VirtualSoundCardOption
from .VirtualSriovEthernetCard import VirtualSriovEthernetCard as VirtualSriovEthernetCard
from .VirtualSriovEthernetCardOption import VirtualSriovEthernetCardOption as VirtualSriovEthernetCardOption
from .VirtualTPM import VirtualTPM as VirtualTPM
from .VirtualTPMOption import VirtualTPMOption as VirtualTPMOption
from .VirtualUSB import VirtualUSB as VirtualUSB
from .VirtualUSBController import VirtualUSBController as VirtualUSBController
from .VirtualUSBControllerOption import VirtualUSBControllerOption as VirtualUSBControllerOption
from .VirtualUSBOption import VirtualUSBOption as VirtualUSBOption
from .VirtualUSBXHCIController import VirtualUSBXHCIController as VirtualUSBXHCIController
from .VirtualUSBXHCIControllerOption import VirtualUSBXHCIControllerOption as VirtualUSBXHCIControllerOption
from .VirtualVMCIDevice import VirtualVMCIDevice as VirtualVMCIDevice
from .VirtualVMCIDeviceOption import VirtualVMCIDeviceOption as VirtualVMCIDeviceOption
from .VirtualVMIROM import VirtualVMIROM as VirtualVMIROM
from .VirtualVMIROMOption import VirtualVMIROMOption as VirtualVMIROMOption
from .VirtualVideoCard import VirtualVideoCard as VirtualVideoCard
from .VirtualVideoCardOption import VirtualVideoCardOption as VirtualVideoCardOption
from .VirtualVmxnet import VirtualVmxnet as VirtualVmxnet
from .VirtualVmxnet2 import VirtualVmxnet2 as VirtualVmxnet2
from .VirtualVmxnet2Option import VirtualVmxnet2Option as VirtualVmxnet2Option
from .VirtualVmxnet3 import VirtualVmxnet3 as VirtualVmxnet3
from .VirtualVmxnet3Option import VirtualVmxnet3Option as VirtualVmxnet3Option
from .VirtualVmxnet3Vrdma import VirtualVmxnet3Vrdma as VirtualVmxnet3Vrdma
from .VirtualVmxnet3VrdmaOption import VirtualVmxnet3VrdmaOption as VirtualVmxnet3VrdmaOption
from .VirtualVmxnetOption import VirtualVmxnetOption as VirtualVmxnetOption
from .VirtualWDT import VirtualWDT as VirtualWDT
from .VirtualWDTOption import VirtualWDTOption as VirtualWDTOption



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VmComponentProtectionSettings
from pyVmomi.vim.cluster import VmToolsMonitoringSettings

class DasVmSettings(DynamicData):
   class RestartPriority(Enum):
      disabled: ClassVar['RestartPriority'] = 'disabled'
      lowest: ClassVar['RestartPriority'] = 'lowest'
      low: ClassVar['RestartPriority'] = 'low'
      medium: ClassVar['RestartPriority'] = 'medium'
      high: ClassVar['RestartPriority'] = 'high'
      highest: ClassVar['RestartPriority'] = 'highest'
      clusterRestartPriority: ClassVar['RestartPriority'] = 'clusterRestartPriority'

   class IsolationResponse(Enum):
      none: ClassVar['IsolationResponse'] = 'none'
      powerOff: ClassVar['IsolationResponse'] = 'powerOff'
      shutdown: ClassVar['IsolationResponse'] = 'shutdown'
      clusterIsolationResponse: ClassVar['IsolationResponse'] = 'clusterIsolationResponse'

   restartPriority: Optional[str] = None
   restartPriorityTimeout: Optional[int] = None
   isolationResponse: Optional[str] = None
   vmToolsMonitoringSettings: Optional[VmToolsMonitoringSettings] = None
   vmComponentProtectionSettings: Optional[VmComponentProtectionSettings] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

class Network(ManagedEntity):
   class Summary(DynamicData):
      network: Optional[Network] = None
      name: str
      accessible: bool
      ipPoolName: str
      ipPoolId: Optional[int] = None

   @property
   def summary(self) -> Summary: ...
   @property
   def host(self) -> list[HostSystem]: ...
   @property
   def vm(self) -> list[VirtualMachine]: ...

   def DestroyNetwork(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.vsan import VsanPrepareVsanForVcsaSpec
from pyVmomi.vim.vsan import VsanVcPostDeployConfigSpec
from pyVmomi.vim.vsan import VsanVcsaDeploymentProgress

class VsanVcsaDeployerSystem(ManagedObject):
   def PrepareVsanForVcsa(self, spec: VsanPrepareVsanForVcsaSpec) -> Optional[str]: ...
   def PostConfigForVcsa(self, spec: VsanVcPostDeployConfigSpec) -> Optional[str]: ...
   def VcsaGetBootstrapProgress(self, taskId: list[str]) -> list[VsanVcsaDeploymentProgress]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

class PortConnectee(DynamicData):
   class ConnecteeType(Enum):
      pnic: ClassVar['ConnecteeType'] = 'pnic'
      vmVnic: ClassVar['ConnecteeType'] = 'vmVnic'
      hostConsoleVnic: ClassVar['ConnecteeType'] = 'hostConsoleVnic'
      hostVmkVnic: ClassVar['ConnecteeType'] = 'hostVmkVnic'
      systemCrxVnic: ClassVar['ConnecteeType'] = 'systemCrxVnic'

   connectedEntity: Optional[ManagedEntity] = None
   nicKey: Optional[str] = None
   type: Optional[str] = None
   addressHint: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vslm import ID

class VStorageObjectSnapshotInfo(DynamicData):
   class VStorageObjectSnapshot(DynamicData):
      id: Optional[ID] = None
      backingObjectId: Optional[str] = None
      createTime: datetime
      description: str

   snapshots: list[VStorageObjectSnapshot] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FileSystemVolume
from pyVmomi.vim.host import MountInfo

class FileSystemMountInfo(DynamicData):
   class VStorageSupportStatus(Enum):
      vStorageSupported: ClassVar['VStorageSupportStatus'] = 'vStorageSupported'
      vStorageUnsupported: ClassVar['VStorageSupportStatus'] = 'vStorageUnsupported'
      vStorageUnknown: ClassVar['VStorageSupportStatus'] = 'vStorageUnknown'

   mountInfo: MountInfo
   volume: FileSystemVolume
   vStorageSupport: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class BatchResult(DynamicData):
   class Result(Enum):
      success: ClassVar['Result'] = 'success'
      fail: ClassVar['Result'] = 'fail'

   result: str
   hostKey: str
   ds: Optional[Datastore] = None
   fault: Optional[MethodFault] = None
